/*
 * This file is loading the irep
 * Ruby GEM code.
 *
 * IMPORTANT:
 *   This file was generated!
 *   All manual changes will get lost.
 */
#include <stdlib.h>
#include <mruby.h>
#include <mruby/irep.h>
#include <mruby/debug.h>
#include <mruby/proc.h>
#include <mruby/presym.h>

#define mrb_BRACED(...) {__VA_ARGS__}
#define mrb_DEFINE_SYMS_VAR(name, len, syms, qualifier) \
  static qualifier mrb_sym name[len] = mrb_BRACED syms

static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_6[1] = {
{IREP_TT_STR|(1<<2), {"\x72"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_6, 5, (MRB_SYM(Integer), MRB_SYM_Q(kind_of), MRB_IVSYM(path), MRB_SYM(IO), MRB_SYM(sysopen), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_6[92] = {
0x33,0x04,0x40,0x00,0x23,0x00,0x06,0x23,0x00,0x06,0x23,0x00,0x08,0x50,0x02,0x00,0x66,0x0e,0x03,0x01,
0xb6,0x01,0x06,0x01,0x1d,0x07,0x00,0x2d,0x06,0x01,0x01,0x25,0x06,0x00,0x12,0x32,0x07,0x00,0x00,0x01,
0x07,0x01,0x01,0x08,0x02,0x11,0x09,0x31,0x06,0x02,0x23,0x00,0x25,0x1a,0x01,0x02,0x1d,0x06,0x03,0x19,
0x07,0x02,0x01,0x08,0x02,0x01,0x09,0x03,0x2d,0x06,0x04,0x03,0x01,0x05,0x06,0x32,0x07,0x00,0x00,0x01,
0x07,0x05,0x01,0x08,0x02,0x11,0x09,0x31,0x06,0x02,0x37,0x06,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_6, 5, (MRB_SYM(fd_or_path), MRB_SYM(mode), MRB_SYM(perm), MRB_OPSYM(and), MRB_SYM(fd), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_6[] = "\x00\x04\x15\x01\x0c\x01\x12\x04\x02\xfe\xff\xff\xff\x0f\x03\x01\x13\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_6 = {
0, 173, 18, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_6}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_6_ = &gem_mrblib_mruby_io_proc_debug_file_6;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_6 = {
92, 1, &gem_mrblib_mruby_io_proc_debug_file_6_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_6 = {
  6,11,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_6,
  gem_mrblib_mruby_io_proc_pool_6,gem_mrblib_mruby_io_proc_syms_6,NULL,
  gem_mrblib_mruby_io_proc_lv_6,
  &gem_mrblib_mruby_io_proc_debug_6,
  92,1,5,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_7, 3, (MRB_SYM(_mtime), MRB_SYM(Time), MRB_SYM(at), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_7[32] = {
0x33,0x00,0x00,0x00,0x12,0x03,0x2d,0x03,0x00,0x00,0x01,0x02,0x03,0x01,0x03,0x02,0x25,0x03,0x00,0x0a,
0x1d,0x03,0x01,0x01,0x04,0x02,0x2d,0x03,0x02,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_7, 2, (MRB_OPSYM(and), MRB_SYM(t), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_7[] = "\x00\x0e\x04\x01\x09\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_7 = {
0, 173, 6, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_7}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_7_ = &gem_mrblib_mruby_io_proc_debug_file_7;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_7 = {
32, 1, &gem_mrblib_mruby_io_proc_debug_file_7_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_7 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_7,
  NULL,gem_mrblib_mruby_io_proc_syms_7,NULL,
  gem_mrblib_mruby_io_proc_lv_7,
  &gem_mrblib_mruby_io_proc_debug_7,
  32,0,3,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_60[3] = {
{IREP_TT_STR|(15<<2), {"\x72\x65\x63\x75\x72\x73\x69\x76\x65\x20\x61\x72\x72\x61\x79"}},
{IREP_TT_STR|(26<<2), {"\x6e\x6f\x20\x69\x6d\x70\x6c\x69\x63\x69\x74\x20\x63\x6f\x6e\x76\x65\x72\x73\x69\x6f\x6e\x20\x6f\x66\x20"}},
{IREP_TT_STR|(12<<2), {"\x20\x69\x6e\x74\x6f\x20\x53\x74\x72\x69\x6e\x67"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_60, 8, (MRB_SYM(String), MRB_OPSYM(eqq), MRB_SYM(Array), MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(join), MRB_SYM(TypeError), MRB_SYM(class), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_60[120] = {
0x33,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x01,0x05,0x03,0x2d,0x04,0x01,0x01,0x24,0x04,0x00,
0x03,0x23,0x00,0x06,0x01,0x04,0x01,0x23,0x00,0x58,0x1d,0x04,0x02,0x01,0x05,0x03,0x2d,0x04,0x01,0x01,
0x24,0x04,0x00,0x03,0x23,0x00,0x28,0x21,0x04,0x01,0x00,0x01,0x05,0x01,0x41,0x04,0x25,0x04,0x00,0x0c,
0x12,0x04,0x1d,0x05,0x03,0x50,0x06,0x00,0x2d,0x04,0x04,0x02,0x12,0x04,0x11,0x05,0x01,0x06,0x01,0x48,
0x05,0x2b,0x04,0x05,0x23,0x00,0x1f,0x12,0x04,0x1d,0x05,0x06,0x50,0x06,0x01,0x01,0x07,0x01,0x2d,0x07,
0x07,0x00,0x51,0x06,0x50,0x07,0x02,0x51,0x06,0x2d,0x04,0x04,0x02,0x23,0x00,0x02,0x11,0x04,0x37,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_60, 2, (MRB_SYM(name), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_60[] = "\x00\x16\x04\x01\x03\x01\x0f\x01\x06\x07\x02\xfa\xff\xff\xff\x0f\x0f\x04\x02\xfd\xff\xff\xff\x0f\x0b\x01\x0e\x02\x0d\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_60 = {
0, 173, 30, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_60}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_60_ = &gem_mrblib_mruby_io_proc_debug_file_60;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_60 = {
120, 1, &gem_mrblib_mruby_io_proc_debug_file_60_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_60 = {
  3,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_60,
  gem_mrblib_mruby_io_proc_pool_60,gem_mrblib_mruby_io_proc_syms_60,NULL,
  gem_mrblib_mruby_io_proc_lv_60,
  &gem_mrblib_mruby_io_proc_debug_60,
  120,3,8,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_61[1] = {
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_61, 4, (MRB_OPSYM(aref), MRB_SYM(SEPARATOR), MRB_SYM(File), MRB_OPSYM(neq), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_61[200] = {
0x33,0x04,0x00,0x00,0x21,0x04,0x01,0x00,0x01,0x05,0x01,0x2d,0x04,0x00,0x01,0x01,0x03,0x04,0x01,0x04,
0x03,0x06,0x05,0x2d,0x04,0x00,0x01,0x1d,0x05,0x02,0x1f,0x05,0x01,0x41,0x04,0x25,0x04,0x00,0x11,0x01,
0x04,0x03,0x05,0x05,0x2d,0x04,0x00,0x01,0x1d,0x05,0x02,0x1f,0x05,0x01,0x41,0x04,0x25,0x04,0x00,0x14,
0x01,0x04,0x03,0x07,0x05,0x04,0x06,0x02,0x58,0x05,0x2d,0x04,0x00,0x01,0x01,0x03,0x04,0x23,0x00,0x4e,
0x01,0x04,0x03,0x06,0x05,0x2d,0x04,0x00,0x01,0x1d,0x05,0x02,0x1f,0x05,0x01,0x41,0x04,0x25,0x04,0x00,
0x13,0x01,0x04,0x03,0x07,0x05,0x05,0x06,0x58,0x05,0x2d,0x04,0x00,0x01,0x01,0x03,0x04,0x23,0x00,0x26,
0x01,0x04,0x03,0x05,0x05,0x2d,0x04,0x00,0x01,0x1d,0x05,0x02,0x1f,0x05,0x01,0x41,0x04,0x25,0x04,0x00,
0x11,0x01,0x04,0x03,0x06,0x05,0x04,0x06,0x02,0x58,0x05,0x2d,0x04,0x00,0x01,0x01,0x03,0x04,0x01,0x04,
0x03,0x50,0x05,0x00,0x2d,0x04,0x03,0x01,0x25,0x04,0x00,0x18,0x21,0x04,0x03,0x00,0x1d,0x05,0x02,0x1f,
0x05,0x01,0x01,0x06,0x03,0x3b,0x05,0x3b,0x04,0x22,0x04,0x03,0x00,0x23,0x00,0x02,0x11,0x04,0x37,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_61, 3, (MRB_SYM(i), MRB_OPSYM(and), MRB_SYM(t), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_61[] = "\x00\x2c\x04\x01\x0e\x01\x28\x01\x14\x04\x02\xfd\xff\xff\xff\x0f\x13\x01\x13\x02\x02\xff\xff\xff\xff\x0f\x13\x01\x13\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_61 = {
0, 173, 30, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_61}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_61_ = &gem_mrblib_mruby_io_proc_debug_file_61;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_61 = {
200, 1, &gem_mrblib_mruby_io_proc_debug_file_61_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_61 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_61,
  gem_mrblib_mruby_io_proc_pool_61,gem_mrblib_mruby_io_proc_syms_61,NULL,
  gem_mrblib_mruby_io_proc_lv_61,
  &gem_mrblib_mruby_io_proc_debug_61,
  200,1,4,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_8[2] = {
  &gem_mrblib_mruby_io_proc_irep_60,
  &gem_mrblib_mruby_io_proc_irep_61,
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_8[1] = {
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_8, 8, (MRB_SYM_Q(empty), MRB_SYM_B(map), MRB_SYM(size), MRB_OPSYM(aref), MRB_SYM(SEPARATOR), MRB_SYM(File), MRB_SYM(dup), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_8[238] = {
0x33,0x00,0x10,0x00,0x01,0x04,0x01,0x2d,0x04,0x00,0x00,0x25,0x04,0x00,0x05,0x50,0x04,0x00,0x37,0x04,
0x01,0x04,0x01,0x56,0x05,0x00,0x2e,0x04,0x01,0x00,0x01,0x04,0x01,0x2d,0x04,0x02,0x00,0x07,0x05,0x41,
0x04,0x25,0x04,0x00,0x0b,0x01,0x04,0x01,0x06,0x05,0x2d,0x04,0x03,0x01,0x37,0x04,0x01,0x04,0x01,0x06,
0x05,0x2d,0x04,0x03,0x01,0x05,0x05,0x2d,0x04,0x03,0x01,0x1d,0x05,0x05,0x1f,0x05,0x04,0x41,0x04,0x25,
0x04,0x00,0x1a,0x01,0x04,0x01,0x06,0x05,0x2d,0x04,0x03,0x01,0x06,0x05,0x04,0x06,0x02,0x58,0x05,0x2d,
0x04,0x03,0x01,0x01,0x03,0x04,0x23,0x00,0x10,0x01,0x04,0x01,0x06,0x05,0x2d,0x04,0x03,0x01,0x2d,0x04,
0x06,0x00,0x01,0x03,0x04,0x07,0x04,0x01,0x05,0x01,0x2d,0x05,0x02,0x00,0x3e,0x05,0x02,0x58,0x04,0x56,
0x05,0x01,0x2e,0x04,0x07,0x00,0x01,0x04,0x01,0x05,0x05,0x2d,0x04,0x03,0x01,0x06,0x05,0x2d,0x04,0x03,
0x01,0x1d,0x05,0x05,0x1f,0x05,0x04,0x41,0x04,0x25,0x04,0x00,0x26,0x01,0x04,0x03,0x1d,0x05,0x05,0x1f,
0x05,0x04,0x01,0x06,0x01,0x05,0x07,0x2d,0x06,0x03,0x01,0x07,0x07,0x05,0x08,0x58,0x07,0x2d,0x06,0x03,
0x01,0x3b,0x05,0x3b,0x04,0x01,0x03,0x04,0x23,0x00,0x19,0x01,0x04,0x03,0x1d,0x05,0x05,0x1f,0x05,0x04,
0x01,0x06,0x01,0x05,0x07,0x2d,0x06,0x03,0x01,0x3b,0x05,0x3b,0x04,0x01,0x03,0x04,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_8, 3, (MRB_SYM(names), MRB_OPSYM(and), MRB_SYM(s), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_8[] = "\x00\x13\x04\x01\x10\x02\x0a\x0e\x1a\x02\x19\x01\x1a\x02\x12\x03\x15\x0b\x19\x01\x26\x02\x1b\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_8 = {
0, 173, 24, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_8}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_8_ = &gem_mrblib_mruby_io_proc_debug_file_8;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_8 = {
238, 1, &gem_mrblib_mruby_io_proc_debug_file_8_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_8 = {
  4,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_8,
  gem_mrblib_mruby_io_proc_pool_8,gem_mrblib_mruby_io_proc_syms_8,gem_mrblib_mruby_io_proc_reps_8,
  gem_mrblib_mruby_io_proc_lv_8,
  &gem_mrblib_mruby_io_proc_debug_8,
  238,1,8,2,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_9[6] = {
{IREP_TT_STR|(1<<2), {"\x2f"}},
{IREP_TT_STR|(1<<2), {"\x3a"}},
{IREP_TT_STR|(1<<2), {"\x7e"}},
{IREP_TT_STR|(47<<2), {"\x63\x6f\x75\x6c\x64\x6e\x27\x74\x20\x66\x69\x6e\x64\x20\x48\x4f\x4d\x45\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x20\x2d\x2d\x20\x65\x78\x70\x61\x6e\x64\x69\x6e\x67\x20\x27\x7e\x27"}},
{IREP_TT_STR|(5<<2), {"\x75\x73\x65\x72\x20"}},
{IREP_TT_STR|(14<<2), {"\x20\x64\x6f\x65\x73\x6e\x27\x74\x20\x65\x78\x69\x73\x74"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_9, 9, (MRB_OPSYM(aref), MRB_SYM(size), MRB_SYM(_gethome), MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(split), MRB_SYM(join), MRB_SYM(_getwd), MRB_SYM(_concat_path), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_9[377] = {
0x33,0x08,0x00,0x00,0x01,0x09,0x01,0x06,0x0a,0x2d,0x09,0x00,0x01,0x50,0x0a,0x00,0x41,0x09,0x24,0x09,
0x00,0x0e,0x01,0x09,0x01,0x07,0x0a,0x2d,0x09,0x00,0x01,0x50,0x0a,0x01,0x41,0x09,0x25,0x09,0x00,0x09,
0x01,0x09,0x01,0x01,0x04,0x09,0x23,0x01,0x46,0x01,0x09,0x01,0x06,0x0a,0x2d,0x09,0x00,0x01,0x50,0x0a,
0x02,0x41,0x09,0x25,0x09,0x01,0x12,0x01,0x09,0x01,0x07,0x0a,0x2d,0x09,0x00,0x01,0x50,0x0a,0x00,0x41,
0x09,0x24,0x09,0x00,0x0d,0x01,0x09,0x01,0x07,0x0a,0x2d,0x09,0x00,0x01,0x11,0x0a,0x41,0x09,0x25,0x09,
0x00,0x55,0x01,0x09,0x01,0x07,0x0a,0x01,0x0b,0x01,0x2d,0x0b,0x01,0x00,0x2d,0x09,0x00,0x02,0x01,0x05,
0x09,0x12,0x09,0x2d,0x09,0x02,0x00,0x01,0x06,0x09,0x01,0x09,0x06,0x24,0x09,0x00,0x0c,0x12,0x09,0x1d,
0x0a,0x03,0x50,0x0b,0x03,0x2d,0x09,0x04,0x02,0x01,0x09,0x06,0x01,0x04,0x09,0x01,0x09,0x05,0x25,0x09,
0x00,0x0b,0x01,0x09,0x04,0x01,0x0a,0x05,0x3b,0x09,0x01,0x04,0x09,0x01,0x09,0x04,0x50,0x0a,0x00,0x3b,
0x09,0x01,0x04,0x09,0x23,0x00,0x97,0x01,0x09,0x01,0x50,0x0a,0x00,0x2d,0x09,0x05,0x01,0x01,0x07,0x09,
0x01,0x09,0x07,0x06,0x0a,0x2d,0x09,0x00,0x01,0x07,0x0a,0x01,0x0b,0x07,0x06,0x0c,0x2d,0x0b,0x00,0x01,
0x2d,0x0b,0x01,0x00,0x2d,0x09,0x00,0x02,0x01,0x08,0x09,0x50,0x09,0x00,0x01,0x0a,0x07,0x07,0x0b,0x01,
0x0c,0x07,0x2d,0x0c,0x01,0x00,0x2d,0x0a,0x00,0x02,0x50,0x0b,0x00,0x2d,0x0a,0x06,0x01,0x3b,0x09,0x01,
0x05,0x09,0x12,0x09,0x01,0x0a,0x08,0x2d,0x09,0x02,0x01,0x01,0x06,0x09,0x01,0x09,0x06,0x24,0x09,0x00,
0x16,0x12,0x09,0x1d,0x0a,0x03,0x50,0x0b,0x04,0x01,0x0c,0x08,0x51,0x0b,0x50,0x0c,0x05,0x51,0x0b,0x2d,
0x09,0x04,0x02,0x01,0x09,0x06,0x01,0x04,0x09,0x01,0x09,0x05,0x25,0x09,0x00,0x0b,0x01,0x09,0x04,0x01,
0x0a,0x05,0x3b,0x09,0x01,0x04,0x09,0x01,0x09,0x04,0x50,0x0a,0x00,0x3b,0x09,0x01,0x04,0x09,0x23,0x00,
0x22,0x12,0x09,0x01,0x0a,0x02,0x12,0x0b,0x2d,0x0b,0x07,0x00,0x2d,0x09,0x08,0x02,0x01,0x04,0x09,0x01,
0x09,0x04,0x50,0x0a,0x00,0x01,0x0b,0x01,0x3b,0x0a,0x3b,0x09,0x01,0x04,0x09,0x37,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_9, 8, (MRB_SYM(path), MRB_SYM(base_path), MRB_OPSYM(and), MRB_SYM(expanded_path), MRB_SYM(dir), MRB_SYM(home_dir), MRB_SYM(splitted_path), MRB_SYM(user), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_9[] = "\x00\x3f\x04\x01\x22\x01\x09\x1e\x02\xe3\xff\xff\xff\x0f\x10\x19\x02\xe8\xff\xff\xff\x0f\x21\x0a\x02\xf7\xff\xff\xff\x0f\x13\x01\x09\x02\x05\x01\x0e\x03\x06\x01\x12\x01\x0c\x0e\x02\xf4\xff\xff\xff\x0f\x0d\x01\x1f\x01\x1f\x02\x0c\x02\x05\x01\x18\x03\x06\x01\x12\x01\x0c\x04\x02\xff\xff\xff\xff\x0f\x12\x01\x10\x03";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_9 = {
0, 173, 78, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_9}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_9_ = &gem_mrblib_mruby_io_proc_debug_file_9;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_9 = {
377, 1, &gem_mrblib_mruby_io_proc_debug_file_9_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_9 = {
  9,14,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_9,
  gem_mrblib_mruby_io_proc_pool_9,gem_mrblib_mruby_io_proc_syms_9,NULL,
  gem_mrblib_mruby_io_proc_lv_9,
  &gem_mrblib_mruby_io_proc_debug_9,
  377,6,9,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_100[2] = {
{IREP_TT_STR|(2<<2), {"\x2e\x2e"}},
{IREP_TT_STR|(1<<2), {"\x2e"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_100, 3, (MRB_SYM(size), MRB_SYM(pop), MRB_OPSYM(lshift), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_100[78] = {
0x33,0x04,0x00,0x00,0x01,0x03,0x01,0x50,0x04,0x00,0x41,0x03,0x25,0x03,0x00,0x20,0x21,0x03,0x06,0x00,
0x2d,0x03,0x00,0x00,0x07,0x04,0x44,0x03,0x25,0x03,0x00,0x0b,0x21,0x03,0x06,0x00,0x2d,0x03,0x01,0x00,
0x23,0x00,0x02,0x11,0x03,0x23,0x00,0x1c,0x01,0x03,0x01,0x50,0x04,0x01,0x41,0x03,0x25,0x03,0x00,0x05,
0x11,0x03,0x23,0x00,0x0b,0x21,0x03,0x06,0x00,0x01,0x04,0x01,0x2d,0x03,0x02,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_100, 2, (MRB_SYM(path_token), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_100[] = "\x00\x76\x04\x01\x0a\x02\x02\xff\xff\xff\xff\x0f\x0e\x01\x10\x05\x02\xfd\xff\xff\xff\x0f\x0a\x02\x05\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_100 = {
0, 173, 26, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_100}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_100_ = &gem_mrblib_mruby_io_proc_debug_file_100;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_100 = {
78, 1, &gem_mrblib_mruby_io_proc_debug_file_100_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_100 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_100,
  gem_mrblib_mruby_io_proc_pool_100,gem_mrblib_mruby_io_proc_syms_100,NULL,
  gem_mrblib_mruby_io_proc_lv_100,
  &gem_mrblib_mruby_io_proc_debug_100,
  78,2,3,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_10[1] = {
  &gem_mrblib_mruby_io_proc_irep_100,
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_10[7] = {
{IREP_TT_STR|(1<<2), {"\x2e"}},
{IREP_TT_STR|(0<<2), {""}},
{IREP_TT_STR|(1<<2), {"\x41"}},
{IREP_TT_STR|(1<<2), {"\x5a"}},
{IREP_TT_STR|(1<<2), {"\x3a"}},
{IREP_TT_STR|(1<<2), {"\x2f"}},
{IREP_TT_STR|(2<<2), {"\x2f\x2f"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_10, 14, (MRB_SYM(_concat_path), MRB_SYM(ALT_SEPARATOR), MRB_SYM(File), MRB_SYM(size), MRB_OPSYM(aref), MRB_SYM(upcase), MRB_SYM_Q(include), MRB_SYM_B(gsub), MRB_SYM(gsub), MRB_OPSYM(neq), MRB_SYM(split), MRB_SYM(each), MRB_SYM(join), MRB_SYM_Q(empty), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_10[316] = {
0x33,0x04,0x20,0x00,0x23,0x00,0x03,0x23,0x00,0x03,0x50,0x02,0x00,0x12,0x07,0x01,0x08,0x01,0x01,0x09,
0x02,0x2d,0x07,0x00,0x02,0x01,0x04,0x07,0x50,0x05,0x01,0x1d,0x07,0x02,0x1f,0x07,0x01,0x25,0x07,0x00,
0x0b,0x01,0x07,0x04,0x2d,0x07,0x03,0x00,0x08,0x08,0x44,0x07,0x25,0x07,0x00,0x19,0x50,0x07,0x02,0x50,
0x08,0x03,0x58,0x07,0x01,0x08,0x04,0x06,0x09,0x2d,0x08,0x04,0x01,0x2d,0x08,0x05,0x00,0x2d,0x07,0x06,
0x01,0x25,0x07,0x00,0x0e,0x01,0x07,0x04,0x07,0x08,0x2d,0x07,0x04,0x01,0x50,0x08,0x04,0x41,0x07,0x25,
0x07,0x00,0x21,0x01,0x07,0x04,0x06,0x08,0x08,0x09,0x2d,0x07,0x04,0x02,0x01,0x05,0x07,0x01,0x07,0x04,
0x08,0x08,0x01,0x09,0x04,0x2d,0x09,0x03,0x00,0x2d,0x07,0x04,0x02,0x01,0x04,0x07,0x46,0x07,0x00,0x01,
0x06,0x07,0x1d,0x07,0x02,0x1f,0x07,0x01,0x25,0x07,0x00,0x0d,0x01,0x07,0x04,0x1d,0x08,0x02,0x1f,0x08,
0x01,0x2d,0x07,0x06,0x01,0x25,0x07,0x00,0x10,0x01,0x07,0x04,0x1d,0x08,0x02,0x1f,0x08,0x01,0x50,0x09,
0x05,0x2d,0x07,0x07,0x02,0x01,0x07,0x04,0x50,0x08,0x06,0x2d,0x07,0x06,0x01,0x25,0x07,0x00,0x13,0x01,
0x07,0x04,0x50,0x08,0x06,0x50,0x09,0x05,0x2d,0x07,0x08,0x02,0x01,0x04,0x07,0x23,0xff,0xdf,0x01,0x07,
0x04,0x50,0x08,0x05,0x2d,0x07,0x09,0x01,0x25,0x07,0x00,0x2c,0x01,0x07,0x04,0x50,0x08,0x05,0x2d,0x07,
0x0a,0x01,0x56,0x08,0x00,0x2e,0x07,0x0b,0x00,0x01,0x07,0x06,0x50,0x08,0x05,0x2d,0x07,0x0c,0x01,0x01,
0x04,0x07,0x01,0x07,0x04,0x2d,0x07,0x0d,0x00,0x25,0x07,0x00,0x03,0x50,0x04,0x05,0x01,0x07,0x05,0x2d,
0x07,0x0d,0x00,0x25,0x07,0x00,0x06,0x01,0x07,0x04,0x23,0x00,0x15,0x01,0x07,0x05,0x01,0x08,0x04,0x50,
0x09,0x05,0x1d,0x0a,0x02,0x1f,0x0a,0x01,0x2d,0x08,0x08,0x02,0x3b,0x07,0x37,0x07,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_10, 6, (MRB_SYM(path), MRB_SYM(default_dir), MRB_OPSYM(and), MRB_SYM(expanded_path), MRB_SYM(drive_prefix), MRB_SYM(expand_path_array), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_10[] = "\x00\x65\x0d\x01\x0f\x01\x03\x01\x17\x01\x2f\x02\x02\xff\xff\xff\xff\x0f\x0e\x01\x13\x02\x06\x01\x19\x01\x12\x02\x0c\x01\x15\x03\x0c\x0f\x02\xf2\xff\xff\xff\x0f\x11\x0c\x0d\x01\x09\x01\x05\x03\x09\x01\x06\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_10 = {
0, 173, 52, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_10}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_10_ = &gem_mrblib_mruby_io_proc_debug_file_10;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_10 = {
316, 1, &gem_mrblib_mruby_io_proc_debug_file_10_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_10 = {
  7,12,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_10,
  gem_mrblib_mruby_io_proc_pool_10,gem_mrblib_mruby_io_proc_syms_10,gem_mrblib_mruby_io_proc_reps_10,
  gem_mrblib_mruby_io_proc_lv_10,
  &gem_mrblib_mruby_io_proc_debug_10,
  316,7,14,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_120, 1, (MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_120[17] = {
0x33,0x04,0x00,0x00,0x01,0x04,0x01,0x3a,0x03,0x08,0x02,0x2d,0x03,0x00,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_120, 2, (MRB_SYM(l), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_120[] = "\x00\x91\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_120 = {
0, 173, 3, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_120}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_120_ = &gem_mrblib_mruby_io_proc_debug_file_120;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_120 = {
17, 1, &gem_mrblib_mruby_io_proc_debug_file_120_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_120 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_120,
  NULL,gem_mrblib_mruby_io_proc_syms_120,NULL,
  gem_mrblib_mruby_io_proc_lv_120,
  &gem_mrblib_mruby_io_proc_debug_120,
  17,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_119[1] = {
  &gem_mrblib_mruby_io_proc_irep_120,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_119, 1, (MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_119[16] = {
0x33,0x04,0x00,0x00,0x01,0x03,0x01,0x56,0x04,0x00,0x2e,0x03,0x00,0x00,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_119, 2, (MRB_SYM(f), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_119[] = "\x00\x90\x01\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_119 = {
0, 173, 5, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_119}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_119_ = &gem_mrblib_mruby_io_proc_debug_file_119;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_119 = {
16, 1, &gem_mrblib_mruby_io_proc_debug_file_119_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_119 = {
  3,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_119,
  NULL,gem_mrblib_mruby_io_proc_syms_119,gem_mrblib_mruby_io_proc_reps_119,
  gem_mrblib_mruby_io_proc_lv_119,
  &gem_mrblib_mruby_io_proc_debug_119,
  16,0,1,1,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_11[1] = {
  &gem_mrblib_mruby_io_proc_irep_119,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_11, 3, (MRB_SYM_Q(block_given), MRB_SYM(open), MRB_SYM(new), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_11[42] = {
0x33,0x04,0x00,0x00,0x12,0x03,0x2d,0x03,0x00,0x00,0x25,0x03,0x00,0x0f,0x12,0x03,0x01,0x04,0x01,0x56,
0x05,0x00,0x2e,0x03,0x01,0x01,0x23,0x00,0x0b,0x12,0x03,0x01,0x04,0x01,0x2d,0x03,0x02,0x01,0x37,0x03,
0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_11, 2, (MRB_SYM(file), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_11[] = "\x00\x8e\x01\x04\x01\x08\x01\x0f\x04";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_11 = {
0, 173, 9, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_11}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_11_ = &gem_mrblib_mruby_io_proc_debug_file_11;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_11 = {
42, 1, &gem_mrblib_mruby_io_proc_debug_file_11_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_11 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_11,
  NULL,gem_mrblib_mruby_io_proc_syms_11,gem_mrblib_mruby_io_proc_reps_11,
  gem_mrblib_mruby_io_proc_lv_11,
  &gem_mrblib_mruby_io_proc_debug_11,
  42,0,3,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_12, 2, (MRB_SYM(FileTest), MRB_SYM_Q(directory), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_12[16] = {
0x33,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2d,0x03,0x01,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_12, 2, (MRB_SYM(file), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_12[] = "\x00\x98\x01\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_12 = {
0, 173, 5, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_12}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_12_ = &gem_mrblib_mruby_io_proc_debug_file_12;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_12 = {
16, 1, &gem_mrblib_mruby_io_proc_debug_file_12_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_12 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_12,
  NULL,gem_mrblib_mruby_io_proc_syms_12,NULL,
  gem_mrblib_mruby_io_proc_lv_12,
  &gem_mrblib_mruby_io_proc_debug_12,
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_13, 2, (MRB_SYM(FileTest), MRB_SYM_Q(exist), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_13[16] = {
0x33,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2d,0x03,0x01,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_13, 2, (MRB_SYM(file), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_13[] = "\x00\x9c\x01\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_13 = {
0, 173, 5, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_13}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_13_ = &gem_mrblib_mruby_io_proc_debug_file_13;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_13 = {
16, 1, &gem_mrblib_mruby_io_proc_debug_file_13_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_13 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_13,
  NULL,gem_mrblib_mruby_io_proc_syms_13,NULL,
  gem_mrblib_mruby_io_proc_lv_13,
  &gem_mrblib_mruby_io_proc_debug_13,
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_14, 2, (MRB_SYM(FileTest), MRB_SYM_Q(exists), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_14[16] = {
0x33,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2d,0x03,0x01,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_14, 2, (MRB_SYM(file), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_14[] = "\x00\xa0\x01\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_14 = {
0, 173, 5, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_14}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_14_ = &gem_mrblib_mruby_io_proc_debug_file_14;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_14 = {
16, 1, &gem_mrblib_mruby_io_proc_debug_file_14_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_14 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_14,
  NULL,gem_mrblib_mruby_io_proc_syms_14,NULL,
  gem_mrblib_mruby_io_proc_lv_14,
  &gem_mrblib_mruby_io_proc_debug_14,
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_15, 2, (MRB_SYM(FileTest), MRB_SYM_Q(file), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_15[16] = {
0x33,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2d,0x03,0x01,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_15, 2, (MRB_SYM(file), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_15[] = "\x00\xa4\x01\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_15 = {
0, 173, 5, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_15}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_15_ = &gem_mrblib_mruby_io_proc_debug_file_15;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_15 = {
16, 1, &gem_mrblib_mruby_io_proc_debug_file_15_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_15 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_15,
  NULL,gem_mrblib_mruby_io_proc_syms_15,NULL,
  gem_mrblib_mruby_io_proc_lv_15,
  &gem_mrblib_mruby_io_proc_debug_15,
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_16, 2, (MRB_SYM(FileTest), MRB_SYM_Q(pipe), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_16[16] = {
0x33,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2d,0x03,0x01,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_16, 2, (MRB_SYM(file), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_16[] = "\x00\xa8\x01\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_16 = {
0, 173, 5, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_16}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_16_ = &gem_mrblib_mruby_io_proc_debug_file_16;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_16 = {
16, 1, &gem_mrblib_mruby_io_proc_debug_file_16_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_16 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_16,
  NULL,gem_mrblib_mruby_io_proc_syms_16,NULL,
  gem_mrblib_mruby_io_proc_lv_16,
  &gem_mrblib_mruby_io_proc_debug_16,
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_17, 2, (MRB_SYM(FileTest), MRB_SYM(size), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_17[16] = {
0x33,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2d,0x03,0x01,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_17, 2, (MRB_SYM(file), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_17[] = "\x00\xac\x01\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_17 = {
0, 173, 5, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_17}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_17_ = &gem_mrblib_mruby_io_proc_debug_file_17;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_17 = {
16, 1, &gem_mrblib_mruby_io_proc_debug_file_17_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_17 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_17,
  NULL,gem_mrblib_mruby_io_proc_syms_17,NULL,
  gem_mrblib_mruby_io_proc_lv_17,
  &gem_mrblib_mruby_io_proc_debug_17,
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_18, 2, (MRB_SYM(FileTest), MRB_SYM_Q(size), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_18[16] = {
0x33,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2d,0x03,0x01,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_18, 2, (MRB_SYM(file), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_18[] = "\x00\xb0\x01\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_18 = {
0, 173, 5, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_18}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_18_ = &gem_mrblib_mruby_io_proc_debug_file_18;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_18 = {
16, 1, &gem_mrblib_mruby_io_proc_debug_file_18_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_18 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_18,
  NULL,gem_mrblib_mruby_io_proc_syms_18,NULL,
  gem_mrblib_mruby_io_proc_lv_18,
  &gem_mrblib_mruby_io_proc_debug_18,
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_19, 2, (MRB_SYM(FileTest), MRB_SYM_Q(socket), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_19[16] = {
0x33,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2d,0x03,0x01,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_19, 2, (MRB_SYM(file), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_19[] = "\x00\xb4\x01\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_19 = {
0, 173, 5, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_19}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_19_ = &gem_mrblib_mruby_io_proc_debug_file_19;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_19 = {
16, 1, &gem_mrblib_mruby_io_proc_debug_file_19_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_19 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_19,
  NULL,gem_mrblib_mruby_io_proc_syms_19,NULL,
  gem_mrblib_mruby_io_proc_lv_19,
  &gem_mrblib_mruby_io_proc_debug_19,
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_20, 2, (MRB_SYM(FileTest), MRB_SYM_Q(symlink), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_20[16] = {
0x33,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2d,0x03,0x01,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_20, 2, (MRB_SYM(file), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_20[] = "\x00\xb8\x01\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_20 = {
0, 173, 5, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_20}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_20_ = &gem_mrblib_mruby_io_proc_debug_file_20;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_20 = {
16, 1, &gem_mrblib_mruby_io_proc_debug_file_20_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_20 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_20,
  NULL,gem_mrblib_mruby_io_proc_syms_20,NULL,
  gem_mrblib_mruby_io_proc_lv_20,
  &gem_mrblib_mruby_io_proc_debug_20,
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_21, 2, (MRB_SYM(FileTest), MRB_SYM_Q(zero), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_21[16] = {
0x33,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x2d,0x03,0x01,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_21, 2, (MRB_SYM(file), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_21[] = "\x00\xbc\x01\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_21 = {
0, 173, 5, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_21}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_21_ = &gem_mrblib_mruby_io_proc_debug_file_21;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_21 = {
16, 1, &gem_mrblib_mruby_io_proc_debug_file_21_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_21 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_21,
  NULL,gem_mrblib_mruby_io_proc_syms_21,NULL,
  gem_mrblib_mruby_io_proc_lv_21,
  &gem_mrblib_mruby_io_proc_debug_21,
  16,0,2,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_22[2] = {
{IREP_TT_STR|(1<<2), {"\x2e"}},
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_22, 4, (MRB_SYM(basename), MRB_SYM(rindex), MRB_SYM_Q(nil), MRB_OPSYM(aref), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_22[72] = {
0x33,0x04,0x00,0x00,0x12,0x05,0x01,0x06,0x01,0x2d,0x05,0x00,0x01,0x01,0x03,0x05,0x01,0x05,0x03,0x50,
0x06,0x00,0x2d,0x05,0x01,0x01,0x01,0x04,0x05,0x01,0x05,0x04,0x06,0x06,0x41,0x05,0x24,0x05,0x00,0x07,
0x01,0x05,0x04,0x2d,0x05,0x02,0x00,0x25,0x05,0x00,0x05,0x50,0x05,0x01,0x37,0x05,0x01,0x05,0x03,0x01,
0x06,0x04,0x05,0x07,0x58,0x06,0x2d,0x05,0x03,0x01,0x37,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_22, 4, (MRB_SYM(filename), MRB_OPSYM(and), MRB_SYM(fname), MRB_SYM(epos), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_22[] = "\x00\xc0\x01\x04\x01\x0c\x01\x0d\x01\x1b\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_22 = {
0, 173, 11, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_22}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_22_ = &gem_mrblib_mruby_io_proc_debug_file_22;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_22 = {
72, 1, &gem_mrblib_mruby_io_proc_debug_file_22_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_22 = {
  5,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_22,
  gem_mrblib_mruby_io_proc_pool_22,gem_mrblib_mruby_io_proc_syms_22,NULL,
  gem_mrblib_mruby_io_proc_lv_22,
  &gem_mrblib_mruby_io_proc_debug_22,
  72,2,4,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_23[2] = {
{IREP_TT_STR|(26<<2), {"\x6e\x6f\x20\x69\x6d\x70\x6c\x69\x63\x69\x74\x20\x63\x6f\x6e\x76\x65\x72\x73\x69\x6f\x6e\x20\x6f\x66\x20"}},
{IREP_TT_STR|(12<<2), {"\x20\x69\x6e\x74\x6f\x20\x53\x74\x72\x69\x6e\x67"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_23, 7, (MRB_SYM(String), MRB_SYM_Q(kind_of), MRB_SYM(to_path), MRB_SYM_Q(respond_to), MRB_SYM(TypeError), MRB_SYM(class), MRB_SYM(raise), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_23[76] = {
0x33,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x2d,0x03,0x01,0x01,0x25,0x03,0x00,0x06,0x01,0x03,
0x01,0x23,0x00,0x32,0x01,0x03,0x01,0x10,0x04,0x02,0x2d,0x03,0x03,0x01,0x25,0x03,0x00,0x0a,0x01,0x03,
0x01,0x2d,0x03,0x02,0x00,0x23,0x00,0x1a,0x12,0x03,0x1d,0x04,0x04,0x50,0x05,0x00,0x01,0x06,0x01,0x2d,
0x06,0x05,0x00,0x51,0x05,0x50,0x06,0x01,0x51,0x05,0x2d,0x03,0x06,0x02,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_23, 2, (MRB_SYM(filename), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_23[] = "\x00\xc7\x01\x04\x01\x0c\x01\x06\x04\x02\xfd\xff\xff\xff\x0f\x0c\x01\x0a\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_23 = {
0, 173, 19, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_23}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_23_ = &gem_mrblib_mruby_io_proc_debug_file_23;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_23 = {
76, 1, &gem_mrblib_mruby_io_proc_debug_file_23_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_23 = {
  3,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_23,
  gem_mrblib_mruby_io_proc_pool_23,gem_mrblib_mruby_io_proc_syms_23,NULL,
  gem_mrblib_mruby_io_proc_lv_23,
  &gem_mrblib_mruby_io_proc_debug_23,
  76,2,7,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_1[18] = {
  &gem_mrblib_mruby_io_proc_irep_6,
  &gem_mrblib_mruby_io_proc_irep_7,
  &gem_mrblib_mruby_io_proc_irep_8,
  &gem_mrblib_mruby_io_proc_irep_9,
  &gem_mrblib_mruby_io_proc_irep_10,
  &gem_mrblib_mruby_io_proc_irep_11,
  &gem_mrblib_mruby_io_proc_irep_12,
  &gem_mrblib_mruby_io_proc_irep_13,
  &gem_mrblib_mruby_io_proc_irep_14,
  &gem_mrblib_mruby_io_proc_irep_15,
  &gem_mrblib_mruby_io_proc_irep_16,
  &gem_mrblib_mruby_io_proc_irep_17,
  &gem_mrblib_mruby_io_proc_irep_18,
  &gem_mrblib_mruby_io_proc_irep_19,
  &gem_mrblib_mruby_io_proc_irep_20,
  &gem_mrblib_mruby_io_proc_irep_21,
  &gem_mrblib_mruby_io_proc_irep_22,
  &gem_mrblib_mruby_io_proc_irep_23,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_1, 19, (MRB_SYM(path), MRB_SYM(attr_accessor), MRB_SYM(initialize), MRB_SYM(mtime), MRB_SYM(join), MRB_SYM(_concat_path), MRB_SYM(expand_path), MRB_SYM(foreach), MRB_SYM_Q(directory), MRB_SYM_Q(exist), MRB_SYM_Q(exists), MRB_SYM_Q(file), MRB_SYM_Q(pipe), MRB_SYM(size), MRB_SYM_Q(size), MRB_SYM_Q(socket), MRB_SYM_Q(symlink), MRB_SYM_Q(zero), MRB_SYM(extname), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_1[187] = {
0x12,0x01,0x10,0x02,0x00,0x2d,0x01,0x01,0x01,0x62,0x01,0x57,0x02,0x00,0x5e,0x01,0x02,0x62,0x01,0x57,
0x02,0x01,0x5e,0x01,0x03,0x12,0x01,0x61,0x01,0x57,0x02,0x02,0x5e,0x01,0x04,0x12,0x01,0x61,0x01,0x57,
0x02,0x03,0x5e,0x01,0x05,0x12,0x01,0x61,0x01,0x57,0x02,0x04,0x5e,0x01,0x06,0x12,0x01,0x61,0x01,0x57,
0x02,0x05,0x5e,0x01,0x07,0x12,0x01,0x61,0x01,0x57,0x02,0x06,0x5e,0x01,0x08,0x12,0x01,0x61,0x01,0x57,
0x02,0x07,0x5e,0x01,0x09,0x12,0x01,0x61,0x01,0x57,0x02,0x08,0x5e,0x01,0x0a,0x12,0x01,0x61,0x01,0x57,
0x02,0x09,0x5e,0x01,0x0b,0x12,0x01,0x61,0x01,0x57,0x02,0x0a,0x5e,0x01,0x0c,0x12,0x01,0x61,0x01,0x57,
0x02,0x0b,0x5e,0x01,0x0d,0x12,0x01,0x61,0x01,0x57,0x02,0x0c,0x5e,0x01,0x0e,0x12,0x01,0x61,0x01,0x57,
0x02,0x0d,0x5e,0x01,0x0f,0x12,0x01,0x61,0x01,0x57,0x02,0x0e,0x5e,0x01,0x10,0x12,0x01,0x61,0x01,0x57,
0x02,0x0f,0x5e,0x01,0x11,0x12,0x01,0x61,0x01,0x57,0x02,0x10,0x5e,0x01,0x12,0x12,0x01,0x61,0x01,0x57,
0x02,0x11,0x5e,0x01,0x00,0x37,0x01,};
static char gem_mrblib_mruby_io_proc_debug_lines_1[] = "\x00\x02\x09\x02\x08\x0a\x08\x05\x0a\x2c\x0a\x26\x0a\x29\x0a\x0a\x0a\x04\x0a\x04\x0a\x04\x0a\x04\x0a\x04\x0a\x04\x0a\x04\x0a\x04\x0a\x04\x0a\x04\x0a\x07";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_1 = {
0, 173, 38, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_1}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_1_ = &gem_mrblib_mruby_io_proc_debug_file_1;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_1 = {
187, 1, &gem_mrblib_mruby_io_proc_debug_file_1_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_1 = {
  1,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_1,
  NULL,gem_mrblib_mruby_io_proc_syms_1,gem_mrblib_mruby_io_proc_reps_1,
  NULL,					/* lv */
  &gem_mrblib_mruby_io_proc_debug_1,
  187,0,19,18,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_342, 5, (MRB_SYM(FNM_SYSCASE), MRB_SYM(FNM_NOESCAPE), MRB_SYM(FNM_PATHNAME), MRB_SYM(FNM_DOTMATCH), MRB_SYM(FNM_CASEFOLD), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_342[28] = {
0x06,0x01,0x1e,0x01,0x00,0x07,0x01,0x1e,0x01,0x01,0x08,0x01,0x1e,0x01,0x02,0x0a,0x01,0x1e,0x01,0x03,
0x03,0x01,0x08,0x1e,0x01,0x04,0x37,0x01,};
static char gem_mrblib_mruby_io_proc_debug_lines_342[] = "\x00\x03\x05\x01\x05\x01\x05\x01\x05\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_342 = {
0, 213, 10, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_342}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_342_ = &gem_mrblib_mruby_io_proc_debug_file_342;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_342 = {
28, 1, &gem_mrblib_mruby_io_proc_debug_file_342_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_342 = {
  1,2,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_342,
  NULL,gem_mrblib_mruby_io_proc_syms_342,NULL,
  NULL,					/* lv */
  &gem_mrblib_mruby_io_proc_debug_342,
  28,0,5,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_2[1] = {
  &gem_mrblib_mruby_io_proc_irep_342,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_2, 1, (MRB_SYM(Constants), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_2[10] = {
0x11,0x01,0x5c,0x01,0x00,0x5d,0x01,0x00,0x37,0x01,};
static char gem_mrblib_mruby_io_proc_debug_lines_2[] = "\x00\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_2 = {
0, 213, 2, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_2}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_2_ = &gem_mrblib_mruby_io_proc_debug_file_2;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_2 = {
10, 1, &gem_mrblib_mruby_io_proc_debug_file_2_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_2 = {
  1,2,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_2,
  NULL,gem_mrblib_mruby_io_proc_syms_2,gem_mrblib_mruby_io_proc_reps_2,
  NULL,					/* lv */
  &gem_mrblib_mruby_io_proc_debug_2,
  10,0,1,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_3, 3, (MRB_SYM(Constants), MRB_SYM(File), MRB_SYM(include), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_3[14] = {
0x12,0x01,0x1d,0x02,0x01,0x1f,0x02,0x00,0x2d,0x01,0x02,0x01,0x37,0x01,};
static char gem_mrblib_mruby_io_proc_debug_lines_3[] = "\x00\x0c";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_3 = {
0, 213, 2, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_3}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_3_ = &gem_mrblib_mruby_io_proc_debug_file_3;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_3 = {
14, 1, &gem_mrblib_mruby_io_proc_debug_file_3_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_3 = {
  1,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_3,
  NULL,gem_mrblib_mruby_io_proc_syms_3,NULL,
  NULL,					/* lv */
  &gem_mrblib_mruby_io_proc_debug_3,
  14,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_353, 5, (MRB_SYM(new), MRB_SYM(call), MRB_SYM_Q(closed), MRB_SYM(close), MRB_SYM(StandardError), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_353[117] = {
0x33,0x00,0x10,0x01,0x12,0x04,0x11,0x05,0x01,0x06,0x01,0x48,0x05,0x2b,0x04,0x00,0x01,0x03,0x04,0x01,
0x04,0x02,0x24,0x04,0x00,0x02,0x37,0x03,0x01,0x05,0x03,0x3a,0x04,0x04,0x00,0x2d,0x04,0x01,0x01,0x28,
0x06,0x01,0x07,0x03,0x2d,0x07,0x02,0x00,0x25,0x07,0x00,0x05,0x11,0x07,0x23,0x00,0x07,0x01,0x07,0x03,
0x2d,0x07,0x03,0x00,0x23,0x00,0x14,0x28,0x07,0x1d,0x08,0x04,0x29,0x07,0x08,0x24,0x08,0x00,0x03,0x23,
0x00,0x03,0x23,0x00,0x02,0x2a,0x07,0x2a,0x06,0x37,0x04,0x01,0x00,0x00,0x00,0x1c,0x00,0x00,0x00,0x27,
0x00,0x00,0x00,0x27,0x00,0x00,0x00,0x00,0x29,0x00,0x00,0x00,0x40,0x00,0x00,0x00,0x43,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_353, 3, (MRB_SYM(args), MRB_SYM(block), MRB_SYM(io), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_353[] = "\x00\x0e\x04\x01\x0f\x02\x09\x03\x0d\x03\x18\x02\x02\xfe\xff\xff\xff\x0f\x02\x01\x0b\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_353 = {
0, 221, 22, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_353}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_353_ = &gem_mrblib_mruby_io_proc_debug_file_353;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_353 = {
91, 1, &gem_mrblib_mruby_io_proc_debug_file_353_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_353 = {
  4,9,2,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_353,
  NULL,gem_mrblib_mruby_io_proc_syms_353,NULL,
  gem_mrblib_mruby_io_proc_lv_353,
  &gem_mrblib_mruby_io_proc_debug_353,
  91,0,5,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_354[2] = {
{IREP_TT_STR|(1<<2), {"\x72"}},
{IREP_TT_STR|(39<<2), {"\x70\x6f\x70\x65\x6e\x20\x69\x73\x20\x6e\x6f\x74\x20\x73\x75\x70\x70\x6f\x72\x74\x65\x64\x20\x6f\x6e\x20\x74\x68\x69\x73\x20\x70\x6c\x61\x74\x66\x6f\x72\x6d"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_354, 9, (MRB_SYM(_popen), MRB_SYM_Q(respond_to), MRB_OPSYM(not), MRB_SYM(NotImplementedError), MRB_SYM(raise), MRB_SYM(call), MRB_SYM_Q(closed), MRB_SYM(close), MRB_SYM(IOError), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_354[167] = {
0x33,0x04,0x40,0x01,0x23,0x00,0x06,0x23,0x00,0x06,0x23,0x00,0x09,0x50,0x02,0x00,0x52,0x06,0x00,0x01,
0x03,0x06,0x12,0x06,0x10,0x07,0x00,0x2d,0x06,0x01,0x01,0x2d,0x06,0x02,0x00,0x25,0x06,0x00,0x0c,0x12,
0x06,0x1d,0x07,0x03,0x50,0x08,0x01,0x2d,0x06,0x04,0x02,0x12,0x06,0x01,0x07,0x01,0x01,0x08,0x02,0x01,
0x09,0x03,0x2d,0x06,0x00,0x03,0x01,0x05,0x06,0x01,0x06,0x04,0x24,0x06,0x00,0x02,0x37,0x05,0x01,0x07,
0x05,0x3a,0x06,0x18,0x00,0x2d,0x06,0x05,0x01,0x28,0x08,0x01,0x09,0x05,0x2d,0x09,0x06,0x00,0x25,0x09,
0x00,0x05,0x11,0x09,0x23,0x00,0x07,0x01,0x09,0x05,0x2d,0x09,0x07,0x00,0x23,0x00,0x14,0x28,0x09,0x1d,
0x0a,0x08,0x29,0x09,0x0a,0x24,0x0a,0x00,0x03,0x23,0x00,0x03,0x23,0x00,0x02,0x2a,0x09,0x2a,0x08,0x37,
0x06,0x01,0x00,0x00,0x00,0x4e,0x00,0x00,0x00,0x59,0x00,0x00,0x00,0x59,0x00,0x00,0x00,0x00,0x5b,0x00,
0x00,0x00,0x72,0x00,0x00,0x00,0x75,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_354, 5, (MRB_SYM(command), MRB_SYM(mode), MRB_SYM(opts), MRB_SYM(block), MRB_SYM(io), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_354[] = "\x00\x1d\x16\x01\x0f\x01\x0e\x02\x12\x01\x09\x03\x0d\x03\x18\x03\x02\xfd\xff\xff\xff\x0f\x02\x01\x0b\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_354 = {
0, 221, 26, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_354}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_354_ = &gem_mrblib_mruby_io_proc_debug_file_354;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_354 = {
141, 1, &gem_mrblib_mruby_io_proc_debug_file_354_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_354 = {
  6,11,2,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_354,
  gem_mrblib_mruby_io_proc_pool_354,gem_mrblib_mruby_io_proc_syms_354,NULL,
  gem_mrblib_mruby_io_proc_lv_354,
  &gem_mrblib_mruby_io_proc_debug_354,
  141,2,9,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_355[1] = {
{IREP_TT_STR|(38<<2), {"\x70\x69\x70\x65\x20\x69\x73\x20\x6e\x6f\x74\x20\x73\x75\x70\x70\x6f\x72\x74\x65\x64\x20\x6f\x6e\x20\x74\x68\x69\x73\x20\x70\x6c\x61\x74\x66\x6f\x72\x6d"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_355, 9, (MRB_SYM(_pipe), MRB_SYM_Q(respond_to), MRB_OPSYM(not), MRB_SYM(NotImplementedError), MRB_SYM(raise), MRB_SYM(IO), MRB_SYM(call), MRB_SYM_Q(closed), MRB_SYM(close), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_355[140] = {
0x33,0x00,0x00,0x01,0x12,0x04,0x10,0x05,0x00,0x2d,0x04,0x01,0x01,0x2d,0x04,0x02,0x00,0x25,0x04,0x00,
0x0c,0x12,0x04,0x1d,0x05,0x03,0x50,0x06,0x00,0x2d,0x04,0x04,0x02,0x01,0x04,0x01,0x25,0x04,0x00,0x4e,
0x1d,0x04,0x05,0x2d,0x04,0x00,0x00,0x4b,0x05,0x04,0x00,0x01,0x02,0x05,0x4b,0x05,0x04,0x01,0x01,0x03,
0x05,0x01,0x05,0x02,0x01,0x06,0x03,0x3a,0x04,0x00,0x00,0x2d,0x04,0x06,0x02,0x28,0x06,0x01,0x07,0x02,
0x2d,0x07,0x07,0x00,0x24,0x07,0x00,0x07,0x01,0x07,0x02,0x2d,0x07,0x08,0x00,0x01,0x07,0x03,0x2d,0x07,
0x07,0x00,0x24,0x07,0x00,0x07,0x01,0x07,0x03,0x2d,0x07,0x08,0x00,0x2a,0x06,0x23,0x00,0x07,0x1d,0x04,
0x05,0x2d,0x04,0x00,0x00,0x37,0x04,0x01,0x00,0x00,0x00,0x28,0x00,0x00,0x00,0x4b,0x00,0x00,0x00,0x4b,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_355, 3, (MRB_SYM(block), MRB_SYM(r), MRB_SYM(w), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_355[] = "\x00\x2f\x04\x01\x0f\x01\x0e\x02\x05\x06\x02\xfc\xff\xff\xff\x0f\x15\x01\x10\x02\x12\x01\x15\x03";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_355 = {
0, 221, 24, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_355}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_355_ = &gem_mrblib_mruby_io_proc_debug_file_355;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_355 = {
127, 1, &gem_mrblib_mruby_io_proc_debug_file_355_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_355 = {
  4,9,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_355,
  gem_mrblib_mruby_io_proc_pool_355,gem_mrblib_mruby_io_proc_syms_355,NULL,
  gem_mrblib_mruby_io_proc_lv_355,
  &gem_mrblib_mruby_io_proc_debug_355,
  127,1,9,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_356[3] = {
{IREP_TT_STR|(0<<2), {""}},
{IREP_TT_STR|(1<<2), {"\x7c"}},
{IREP_TT_STR|(1<<2), {"\x72"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_356, 15, (MRB_SYM_Q(nil), MRB_OPSYM(not), MRB_SYM(Hash), MRB_SYM_Q(is_a), MRB_OPSYM(aref), MRB_SYM(IO), MRB_SYM(mode), MRB_SYM(popen), MRB_SYM(sysopen), MRB_SYM(open), MRB_SYM(seek), MRB_SYM(read), MRB_SYM(close), MRB_OPSYM(neq), MRB_SYM(_sysclose), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_356[371] = {
0x33,0x04,0x60,0x00,0x23,0x00,0x09,0x23,0x00,0x08,0x23,0x00,0x07,0x23,0x00,0x06,0x11,0x02,0x11,0x03,
0x11,0x04,0x01,0x0a,0x04,0x2d,0x0a,0x00,0x00,0x2d,0x0a,0x01,0x00,0x25,0x0a,0x00,0x0c,0x01,0x0a,0x03,
0x24,0x0a,0x00,0x02,0x06,0x03,0x23,0x00,0x70,0x01,0x0a,0x03,0x2d,0x0a,0x00,0x00,0x2d,0x0a,0x01,0x00,
0x25,0x0a,0x00,0x22,0x01,0x0a,0x03,0x1d,0x0b,0x02,0x2d,0x0a,0x03,0x01,0x25,0x0a,0x00,0x0b,0x01,0x0a,
0x03,0x01,0x04,0x0a,0x06,0x03,0x23,0x00,0x06,0x52,0x0a,0x00,0x01,0x04,0x0a,0x23,0x00,0x3f,0x01,0x0a,
0x02,0x2d,0x0a,0x00,0x00,0x2d,0x0a,0x01,0x00,0x25,0x0a,0x00,0x26,0x01,0x0a,0x02,0x1d,0x0b,0x02,0x2d,
0x0a,0x03,0x01,0x25,0x0a,0x00,0x0d,0x01,0x0a,0x02,0x01,0x04,0x0a,0x06,0x03,0x11,0x02,0x23,0x00,0x08,
0x06,0x03,0x52,0x0a,0x00,0x01,0x04,0x0a,0x23,0x00,0x0a,0x52,0x0a,0x00,0x01,0x04,0x0a,0x06,0x03,0x11,
0x02,0x50,0x06,0x00,0x05,0x07,0x11,0x08,0x01,0x0a,0x01,0x06,0x0b,0x2d,0x0a,0x04,0x01,0x50,0x0b,0x01,
0x41,0x0a,0x25,0x0a,0x00,0x2b,0x1d,0x0a,0x05,0x01,0x0b,0x01,0x07,0x0c,0x05,0x0d,0x58,0x0c,0x2d,0x0b,
0x04,0x01,0x01,0x0c,0x04,0x10,0x0d,0x06,0x2d,0x0c,0x04,0x01,0x24,0x0c,0x00,0x03,0x50,0x0c,0x02,0x2d,
0x0a,0x07,0x02,0x01,0x08,0x0a,0x23,0x00,0x34,0x01,0x0a,0x04,0x10,0x0b,0x06,0x2d,0x0a,0x04,0x01,0x24,
0x0a,0x00,0x03,0x50,0x0a,0x02,0x01,0x09,0x0a,0x1d,0x0a,0x05,0x01,0x0b,0x01,0x01,0x0c,0x09,0x2d,0x0a,
0x08,0x02,0x01,0x07,0x0a,0x1d,0x0a,0x05,0x01,0x0b,0x07,0x01,0x0c,0x09,0x2d,0x0a,0x09,0x02,0x01,0x08,
0x0a,0x01,0x0a,0x03,0x06,0x0b,0x44,0x0a,0x25,0x0a,0x00,0x0a,0x01,0x0a,0x08,0x01,0x0b,0x03,0x2d,0x0a,
0x0a,0x01,0x01,0x0a,0x08,0x01,0x0b,0x02,0x2d,0x0a,0x0b,0x01,0x01,0x06,0x0a,0x28,0x0b,0x25,0x08,0x00,
0x0a,0x01,0x0c,0x08,0x2d,0x0c,0x0c,0x00,0x23,0x00,0x17,0x01,0x0c,0x07,0x05,0x0d,0x2d,0x0c,0x0d,0x01,
0x25,0x0c,0x00,0x0a,0x1d,0x0c,0x05,0x01,0x0d,0x07,0x2d,0x0c,0x0e,0x01,0x2a,0x0b,0x37,0x06,0x01,0x00,
0x00,0x00,0xa8,0x00,0x00,0x01,0x3b,0x00,0x00,0x01,0x3b,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_356, 9, (MRB_SYM(path), MRB_SYM(length), MRB_SYM(offset), MRB_SYM(opt), MRB_OPSYM(and), MRB_SYM(str), MRB_SYM(fd), MRB_SYM(io), MRB_SYM(mode), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_356[] = "\x00\x40\x16\x01\x0d\x01\x0c\x14\x02\xed\xff\xff\xff\x0f\x0d\x05\x02\xfc\xff\xff\xff\x0f\x0c\x02\x02\xff\xff\xff\xff\x0f\x06\x01\x03\x02\x09\x0e\x02\xf4\xff\xff\xff\x0f\x0d\x07\x02\xfa\xff\xff\xff\x0f\x0c\x03\x02\xfe\xff\xff\xff\x0f\x06\x01\x02\x01\x03\x03\x02\xff\xff\xff\xff\x0f\x02\x01\x07\x05\x02\xfe\xff\xff\xff\x0f\x06\x01\x02\x01\x02\x03\x03\x01\x02\x01\x02\x02\x10\x01\x2b\x04\x02\xfe\xff\xff\xff\x0f\x14\x01\x10\x01\x10\x02\x15\x01\x0f\x02\x02\x01\x0a\x02\x02\xff\xff\xff\xff\x0f\x0b\x01\x0e\x03";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_356 = {
0, 221, 126, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_356}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_356_ = &gem_mrblib_mruby_io_proc_debug_file_356;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_356 = {
358, 1, &gem_mrblib_mruby_io_proc_debug_file_356_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_356 = {
  10,15,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_356,
  gem_mrblib_mruby_io_proc_pool_356,gem_mrblib_mruby_io_proc_syms_356,NULL,
  gem_mrblib_mruby_io_proc_lv_356,
  &gem_mrblib_mruby_io_proc_debug_356,
  358,3,15,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_357[1] = {
{IREP_TT_STR|(13<<2), {"\x63\x6c\x6f\x73\x65\x64\x20\x73\x74\x72\x65\x61\x6d"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_357, 3, (MRB_SYM_Q(closed), MRB_SYM(IOError), MRB_SYM(raise), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_357[30] = {
0x33,0x00,0x00,0x00,0x12,0x02,0x2d,0x02,0x00,0x00,0x25,0x02,0x00,0x0c,0x12,0x02,0x1d,0x03,0x01,0x50,
0x04,0x00,0x2d,0x02,0x02,0x02,0x12,0x02,0x37,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_357, 1, (MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_357[] = "\x00\x70\x04\x02\x16\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_357 = {
0, 221, 6, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_357}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_357_ = &gem_mrblib_mruby_io_proc_debug_file_357;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_357 = {
30, 1, &gem_mrblib_mruby_io_proc_debug_file_357_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_357 = {
  2,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_357,
  gem_mrblib_mruby_io_proc_pool_357,gem_mrblib_mruby_io_proc_syms_357,NULL,
  gem_mrblib_mruby_io_proc_lv_357,
  &gem_mrblib_mruby_io_proc_debug_357,
  30,1,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_358, 1, (MRB_SYM(__id__), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_358[12] = {
0x33,0x00,0x00,0x00,0x12,0x02,0x2d,0x02,0x00,0x00,0x37,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_358, 1, (MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_358[] = "\x00\x76\x04\x03";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_358 = {
0, 221, 4, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_358}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_358_ = &gem_mrblib_mruby_io_proc_debug_file_358;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_358 = {
12, 1, &gem_mrblib_mruby_io_proc_debug_file_358_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_358 = {
  2,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_358,
  NULL,gem_mrblib_mruby_io_proc_syms_358,NULL,
  gem_mrblib_mruby_io_proc_lv_358,
  &gem_mrblib_mruby_io_proc_debug_358,
  12,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_359, 9, (MRB_SYM(String), MRB_SYM_Q(is_a), MRB_SYM(to_s), MRB_SYM_Q(empty), MRB_IVSYM(buf), MRB_SYM(pos), MRB_SYM(SEEK_SET), MRB_SYM(seek), MRB_SYM(syswrite), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_359[89] = {
0x33,0x04,0x00,0x00,0x01,0x05,0x01,0x1d,0x06,0x00,0x2d,0x05,0x01,0x01,0x25,0x05,0x00,0x06,0x01,0x05,
0x01,0x23,0x00,0x07,0x01,0x05,0x01,0x2d,0x05,0x02,0x00,0x01,0x03,0x05,0x01,0x05,0x03,0x2d,0x05,0x03,
0x00,0x25,0x05,0x00,0x04,0x06,0x05,0x37,0x05,0x19,0x05,0x04,0x2d,0x05,0x03,0x00,0x24,0x05,0x00,0x0f,
0x12,0x05,0x12,0x06,0x2d,0x06,0x05,0x00,0x1d,0x07,0x06,0x2d,0x05,0x07,0x02,0x12,0x05,0x01,0x06,0x03,
0x2d,0x05,0x08,0x01,0x01,0x04,0x05,0x37,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_359, 4, (MRB_SYM(string), MRB_OPSYM(and), MRB_SYM(str), MRB_SYM(len), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_359[] = "\x00\x7c\x04\x01\x1e\x01\x0f\x01\x09\x02\x11\x02\x0c\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_359 = {
0, 221, 14, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_359}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_359_ = &gem_mrblib_mruby_io_proc_debug_file_359;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_359 = {
89, 1, &gem_mrblib_mruby_io_proc_debug_file_359_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_359 = {
  5,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_359,
  NULL,gem_mrblib_mruby_io_proc_syms_359,NULL,
  gem_mrblib_mruby_io_proc_lv_359,
  &gem_mrblib_mruby_io_proc_debug_359,
  89,0,9,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_360, 1, (MRB_SYM(write), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_360[17] = {
0x33,0x04,0x00,0x00,0x12,0x03,0x01,0x04,0x01,0x2d,0x03,0x00,0x01,0x12,0x03,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_360, 2, (MRB_SYM(str), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_360[] = "\x00\x87\x01\x04\x01\x09\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_360 = {
0, 221, 7, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_360}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_360_ = &gem_mrblib_mruby_io_proc_debug_file_360;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_360 = {
17, 1, &gem_mrblib_mruby_io_proc_debug_file_360_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_360 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_360,
  NULL,gem_mrblib_mruby_io_proc_syms_360,NULL,
  gem_mrblib_mruby_io_proc_lv_360,
  &gem_mrblib_mruby_io_proc_debug_360,
  17,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_361, 5, (MRB_SYM(_check_readable), MRB_SYM(_read_buf), MRB_IVSYM(buf), MRB_SYM_Q(empty), MRB_SYM(EOFError), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_361[67] = {
0x33,0x00,0x00,0x00,0x12,0x02,0x2d,0x02,0x00,0x00,0x12,0x02,0x2d,0x02,0x01,0x00,0x19,0x02,0x02,0x2d,
0x02,0x03,0x00,0x38,0x02,0x23,0x00,0x18,0x28,0x02,0x1d,0x03,0x04,0x29,0x02,0x03,0x24,0x03,0x00,0x03,
0x23,0x00,0x07,0x13,0x02,0x38,0x02,0x23,0x00,0x02,0x2a,0x02,0x37,0x02,0x00,0x00,0x00,0x00,0x0a,0x00,
0x00,0x00,0x19,0x00,0x00,0x00,0x1c,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_361, 1, (MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_361[] = "\x00\x8c\x01\x04\x01\x06\x02\x06\x01\x0a\x02\x02\xfe\xff\xff\xff\x0f\x02\x01\x0b\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_361 = {
0, 221, 21, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_361}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_361_ = &gem_mrblib_mruby_io_proc_debug_file_361;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_361 = {
54, 1, &gem_mrblib_mruby_io_proc_debug_file_361_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_361 = {
  2,4,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_361,
  NULL,gem_mrblib_mruby_io_proc_syms_361,NULL,
  gem_mrblib_mruby_io_proc_lv_361,
  &gem_mrblib_mruby_io_proc_debug_361,
  54,0,5,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_362, 7, (MRB_SYM_Q(closed), MRB_SYM(IOError), MRB_SYM(raise), MRB_SYM(SEEK_CUR), MRB_SYM(sysseek), MRB_IVSYM(buf), MRB_SYM(bytesize), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_362[45] = {
0x33,0x00,0x00,0x00,0x12,0x02,0x2d,0x02,0x00,0x00,0x25,0x02,0x00,0x09,0x12,0x02,0x1d,0x03,0x01,0x2d,
0x02,0x02,0x01,0x12,0x02,0x06,0x03,0x1d,0x04,0x03,0x2d,0x02,0x04,0x02,0x19,0x03,0x05,0x2d,0x03,0x06,
0x00,0x3d,0x02,0x37,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_362, 1, (MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_362[] = "\x00\x97\x01\x04\x01\x13\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_362 = {
0, 221, 7, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_362}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_362_ = &gem_mrblib_mruby_io_proc_debug_file_362;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_362 = {
45, 1, &gem_mrblib_mruby_io_proc_debug_file_362_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_362 = {
  2,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_362,
  NULL,gem_mrblib_mruby_io_proc_syms_362,NULL,
  gem_mrblib_mruby_io_proc_lv_362,
  &gem_mrblib_mruby_io_proc_debug_362,
  45,0,7,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_363, 2, (MRB_SYM(SEEK_SET), MRB_SYM(seek), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_363[18] = {
0x33,0x04,0x00,0x00,0x12,0x03,0x01,0x04,0x01,0x1d,0x05,0x00,0x2d,0x03,0x01,0x02,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_363, 2, (MRB_SYM(i), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_363[] = "\x00\x9d\x01\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_363 = {
0, 221, 5, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_363}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_363_ = &gem_mrblib_mruby_io_proc_debug_file_363;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_363 = {
18, 1, &gem_mrblib_mruby_io_proc_debug_file_363_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_363 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_363,
  NULL,gem_mrblib_mruby_io_proc_syms_363,NULL,
  gem_mrblib_mruby_io_proc_lv_363,
  &gem_mrblib_mruby_io_proc_debug_363,
  18,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_364, 2, (MRB_SYM(SEEK_SET), MRB_SYM(seek), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_364[17] = {
0x33,0x00,0x00,0x00,0x12,0x02,0x06,0x03,0x1d,0x04,0x00,0x2d,0x02,0x01,0x02,0x37,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_364, 1, (MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_364[] = "\x00\xa1\x01\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_364 = {
0, 221, 5, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_364}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_364_ = &gem_mrblib_mruby_io_proc_debug_file_364;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_364 = {
17, 1, &gem_mrblib_mruby_io_proc_debug_file_364_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_364 = {
  2,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_364,
  NULL,gem_mrblib_mruby_io_proc_syms_364,NULL,
  gem_mrblib_mruby_io_proc_lv_364,
  &gem_mrblib_mruby_io_proc_debug_364,
  17,0,2,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_365[1] = {
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_365, 6, (MRB_SYM(SEEK_SET), MRB_SYM_Q(closed), MRB_SYM(IOError), MRB_SYM(raise), MRB_SYM(sysseek), MRB_IVSYM(buf), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_365[54] = {
0x33,0x04,0x20,0x00,0x23,0x00,0x03,0x23,0x00,0x03,0x1d,0x02,0x00,0x12,0x04,0x2d,0x04,0x01,0x00,0x25,
0x04,0x00,0x09,0x12,0x04,0x1d,0x05,0x02,0x2d,0x04,0x03,0x01,0x12,0x04,0x01,0x05,0x01,0x01,0x06,0x02,
0x2d,0x04,0x04,0x02,0x50,0x04,0x00,0x1a,0x04,0x05,0x06,0x04,0x37,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_365, 3, (MRB_SYM(i), MRB_SYM(whence), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_365[] = "\x00\xa5\x01\x0d\x01\x13\x01\x0c\x01\x06\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_365 = {
0, 221, 11, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_365}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_365_ = &gem_mrblib_mruby_io_proc_debug_file_365;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_365 = {
54, 1, &gem_mrblib_mruby_io_proc_debug_file_365_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_365 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_365,
  gem_mrblib_mruby_io_proc_pool_365,gem_mrblib_mruby_io_proc_syms_365,NULL,
  gem_mrblib_mruby_io_proc_lv_365,
  &gem_mrblib_mruby_io_proc_debug_365,
  54,1,6,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_366, 4, (MRB_IVSYM(buf), MRB_SYM(bytesize), MRB_SYM(BUF_SIZE), MRB_SYM(sysread), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_366[45] = {
0x33,0x00,0x00,0x00,0x19,0x02,0x00,0x25,0x02,0x00,0x0b,0x19,0x02,0x00,0x2d,0x02,0x01,0x00,0x06,0x03,
0x44,0x02,0x25,0x02,0x00,0x05,0x19,0x02,0x00,0x37,0x02,0x12,0x02,0x1d,0x03,0x02,0x19,0x04,0x00,0x2d,
0x02,0x03,0x02,0x37,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_366, 1, (MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_366[] = "\x00\xac\x01\x04\x01\x1b\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_366 = {
0, 221, 7, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_366}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_366_ = &gem_mrblib_mruby_io_proc_debug_file_366;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_366 = {
45, 1, &gem_mrblib_mruby_io_proc_debug_file_366_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_366 = {
  2,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_366,
  NULL,gem_mrblib_mruby_io_proc_syms_366,NULL,
  gem_mrblib_mruby_io_proc_lv_366,
  &gem_mrblib_mruby_io_proc_debug_366,
  45,0,4,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_367[2] = {
{IREP_TT_STR|(19<<2), {"\x65\x78\x70\x65\x63\x74\x20\x53\x74\x72\x69\x6e\x67\x2c\x20\x67\x6f\x74\x20"}},
{IREP_TT_STR|(0<<2), {""}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_367, 10, (MRB_SYM(String), MRB_SYM_Q(is_a), MRB_SYM(TypeError), MRB_SYM(class), MRB_SYM(new), MRB_SYM(raise), MRB_IVSYM(buf), MRB_SYM_Q(empty), MRB_SYM(replace), MRB_OPSYM(aset), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_367[93] = {
0x33,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x2d,0x03,0x01,0x01,0x24,0x03,0x00,0x1e,0x12,0x03,
0x1d,0x04,0x02,0x50,0x05,0x00,0x01,0x06,0x01,0x2d,0x06,0x03,0x00,0x51,0x05,0x50,0x06,0x01,0x51,0x05,
0x2d,0x04,0x04,0x01,0x2d,0x03,0x05,0x01,0x19,0x03,0x06,0x2d,0x03,0x07,0x00,0x25,0x03,0x00,0x0d,0x19,
0x03,0x06,0x01,0x04,0x01,0x2d,0x03,0x08,0x01,0x23,0x00,0x11,0x01,0x03,0x01,0x19,0x04,0x06,0x06,0x05,
0x06,0x06,0x01,0x07,0x03,0x2d,0x04,0x09,0x03,0x11,0x03,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_367, 2, (MRB_SYM(substr), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_367[] = "\x00\xb1\x01\x04\x01\x2c\x01\x09\x01\x0d\x02\x13\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_367 = {
0, 221, 13, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_367}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_367_ = &gem_mrblib_mruby_io_proc_debug_file_367;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_367 = {
93, 1, &gem_mrblib_mruby_io_proc_debug_file_367_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_367 = {
  3,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_367,
  gem_mrblib_mruby_io_proc_pool_367,gem_mrblib_mruby_io_proc_syms_367,NULL,
  gem_mrblib_mruby_io_proc_lv_367,
  &gem_mrblib_mruby_io_proc_debug_367,
  93,2,10,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_368[1] = {
{IREP_TT_STR|(1<<2), {"\x20"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_368, 6, (MRB_SYM(String), MRB_SYM_Q(is_a), MRB_SYM(getbyte), MRB_OPSYM(and), MRB_SYM(setbyte), MRB_SYM(ungetc), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_368[72] = {
0x33,0x04,0x00,0x00,0x01,0x04,0x01,0x1d,0x05,0x00,0x2d,0x04,0x01,0x01,0x25,0x04,0x00,0x0f,0x01,0x04,
0x01,0x06,0x05,0x2d,0x04,0x02,0x01,0x01,0x01,0x04,0x23,0x00,0x0d,0x01,0x04,0x01,0x03,0x05,0xff,0x2d,
0x04,0x03,0x01,0x01,0x01,0x04,0x50,0x03,0x00,0x01,0x04,0x03,0x06,0x05,0x01,0x06,0x01,0x2d,0x04,0x04,
0x02,0x12,0x04,0x01,0x05,0x03,0x2d,0x04,0x05,0x01,0x37,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_368, 3, (MRB_SYM(c), MRB_OPSYM(and), MRB_SYM(s), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_368[] = "\x00\xbb\x01\x04\x01\x0c\x01\x0f\x02\x0f\x02\x03\x01\x0c\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_368 = {
0, 221, 15, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_368}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_368_ = &gem_mrblib_mruby_io_proc_debug_file_368;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_368 = {
72, 1, &gem_mrblib_mruby_io_proc_debug_file_368_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_368 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_368,
  gem_mrblib_mruby_io_proc_pool_368,gem_mrblib_mruby_io_proc_syms_368,NULL,
  gem_mrblib_mruby_io_proc_lv_368,
  &gem_mrblib_mruby_io_proc_debug_368,
  72,1,6,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_369[5] = {
{IREP_TT_STR|(0<<2), {""}},
{IREP_TT_STR|(14<<2), {"\x63\x61\x6e\x27\x74\x20\x63\x6f\x6e\x76\x65\x72\x74\x20"}},
{IREP_TT_STR|(13<<2), {"\x20\x69\x6e\x74\x6f\x20\x49\x6e\x74\x65\x67\x65\x72"}},
{IREP_TT_STR|(17<<2), {"\x6e\x65\x67\x61\x74\x69\x76\x65\x20\x6c\x65\x6e\x67\x74\x68\x3a\x20"}},
{IREP_TT_STR|(6<<2), {"\x20\x67\x69\x76\x65\x6e"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_369, 20, (MRB_SYM(Integer), MRB_SYM_Q(is_a), MRB_SYM(TypeError), MRB_SYM(class), MRB_SYM(new), MRB_SYM(raise), MRB_SYM(ArgumentError), MRB_SYM(_read_buf), MRB_SYM(EOFError), MRB_SYM_Q(empty), MRB_SYM_Q(nil), MRB_OPSYM(not), MRB_OPSYM(neq), MRB_IVSYM(buf), MRB_SYM(bytesize), MRB_SYM(IO), MRB_SYM(_bufread), MRB_SYM(push), MRB_SYM(replace), MRB_SYM(join), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_369[361] = {
0x33,0x00,0x40,0x00,0x23,0x00,0x06,0x23,0x00,0x05,0x23,0x00,0x05,0x11,0x01,0x50,0x02,0x00,0x01,0x06,
0x01,0x26,0x06,0x00,0x61,0x01,0x06,0x01,0x1d,0x07,0x00,0x2d,0x06,0x01,0x01,0x24,0x06,0x00,0x1e,0x12,
0x06,0x1d,0x07,0x02,0x50,0x08,0x01,0x01,0x09,0x01,0x2d,0x09,0x03,0x00,0x51,0x08,0x50,0x09,0x02,0x51,
0x08,0x2d,0x07,0x04,0x01,0x2d,0x06,0x05,0x01,0x01,0x06,0x01,0x06,0x07,0x42,0x06,0x25,0x06,0x00,0x1a,
0x12,0x06,0x1d,0x07,0x06,0x50,0x08,0x03,0x01,0x09,0x01,0x51,0x08,0x50,0x09,0x04,0x51,0x08,0x2d,0x07,
0x04,0x01,0x2d,0x06,0x05,0x01,0x01,0x06,0x01,0x06,0x07,0x41,0x06,0x25,0x06,0x00,0x05,0x50,0x06,0x00,
0x37,0x06,0x46,0x06,0x00,0x01,0x04,0x06,0x12,0x06,0x2d,0x06,0x07,0x00,0x23,0x00,0x40,0x28,0x06,0x1d,
0x07,0x08,0x29,0x06,0x07,0x24,0x07,0x00,0x03,0x23,0x00,0x2f,0x01,0x06,0x04,0x2d,0x06,0x09,0x00,0x25,
0x06,0x00,0x0b,0x01,0x06,0x01,0x2d,0x06,0x0a,0x00,0x2d,0x06,0x0b,0x00,0x25,0x06,0x00,0x09,0x01,0x06,
0x01,0x06,0x07,0x2d,0x06,0x0c,0x01,0x25,0x06,0x00,0x02,0x11,0x04,0x27,0x00,0x6f,0x23,0x00,0x02,0x2a,
0x06,0x01,0x06,0x01,0x25,0x06,0x00,0x50,0x01,0x06,0x01,0x19,0x07,0x0d,0x2d,0x07,0x0e,0x00,0x43,0x06,
0x25,0x06,0x00,0x06,0x01,0x06,0x01,0x23,0x00,0x07,0x19,0x06,0x0d,0x2d,0x06,0x0e,0x00,0x01,0x05,0x06,
0x01,0x06,0x04,0x1d,0x07,0x0f,0x19,0x08,0x0d,0x01,0x09,0x05,0x2d,0x07,0x10,0x02,0x2d,0x06,0x11,0x01,
0x01,0x06,0x01,0x01,0x07,0x05,0x3d,0x06,0x01,0x01,0x06,0x01,0x06,0x01,0x06,0x07,0x41,0x06,0x25,0x06,
0x00,0x03,0x27,0x00,0x16,0x23,0x00,0x10,0x01,0x06,0x04,0x19,0x07,0x0d,0x2d,0x06,0x11,0x01,0x50,0x06,
0x00,0x1a,0x06,0x0d,0x23,0xff,0x4d,0x01,0x06,0x04,0x26,0x06,0x00,0x03,0x23,0x00,0x0f,0x01,0x06,0x02,
0x50,0x07,0x00,0x2d,0x06,0x12,0x01,0x11,0x06,0x23,0x00,0x0e,0x01,0x06,0x02,0x01,0x07,0x04,0x2d,0x07,
0x13,0x00,0x2d,0x06,0x12,0x01,0x37,0x06,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x86,0x00,0x00,0x00,
0x89,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_369, 5, (MRB_SYM(length), MRB_SYM(outbuf), MRB_OPSYM(and), MRB_SYM(array), MRB_SYM(consume), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_369[] = "\x00\xc6\x01\x12\x01\x05\x08\x02\xf9\xff\xff\xff\x0f\x0c\x01\x20\x02\x09\x01\x1c\x02\x09\x01\x07\x04\x06\x03\x07\x03\x02\xfd\xff\xff\xff\x0f\x02\x01\x0b\x02\x02\xff\xff\xff\xff\x0f\x29\x01\x01\x0a\x02\xf6\xff\xff\xff\x0f\x05\x03\x05\x04\x02\xfd\xff\xff\xff\x0f\x20\x01\x14\x01\x0b\x01\x0c\x03\x02\xfd\xff\xff\xff\x0f\x01\x03\x02\xff\xff\xff\xff\x0f\x0a\x01\x09\x04\x08\x02\x02\xff\xff\xff\xff\x0f\x0a\x01\x03\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_369 = {
0, 221, 103, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_369}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_369_ = &gem_mrblib_mruby_io_proc_debug_file_369;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_369 = {
348, 1, &gem_mrblib_mruby_io_proc_debug_file_369_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_369 = {
  6,11,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_369,
  gem_mrblib_mruby_io_proc_pool_369,gem_mrblib_mruby_io_proc_syms_369,NULL,
  gem_mrblib_mruby_io_proc_lv_369,
  &gem_mrblib_mruby_io_proc_debug_369,
  348,5,20,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_370[4] = {
{IREP_TT_STR|(1<<2), {"\x0a"}},
{IREP_TT_STR|(0<<2), {""}},
{IREP_TT_STR|(2<<2), {"\x0a\x0a"}},
{IREP_TT_STR|(19<<2), {"\x65\x6e\x64\x20\x6f\x66\x20\x66\x69\x6c\x65\x20\x72\x65\x61\x63\x68\x65\x64"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_370, 17, (MRB_SYM(String), MRB_OPSYM(eqq), MRB_SYM(Integer), MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(read), MRB_SYM(_read_buf), MRB_SYM(EOFError), MRB_SYM_Q(empty), MRB_IVSYM(buf), MRB_SYM(size), MRB_OPSYM(aref), MRB_SYM(push), MRB_OPSYM(aset), MRB_SYM(index), MRB_SYM(new), MRB_SYM(join), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_370[380] = {
0x33,0x00,0x40,0x00,0x23,0x00,0x06,0x23,0x00,0x06,0x23,0x00,0x05,0x50,0x01,0x00,0x11,0x02,0x01,0x08,
0x01,0x1d,0x09,0x00,0x01,0x0a,0x08,0x2d,0x09,0x01,0x01,0x24,0x09,0x00,0x03,0x23,0x00,0x09,0x01,0x09,
0x01,0x01,0x04,0x09,0x23,0x00,0x29,0x1d,0x09,0x02,0x01,0x0a,0x08,0x2d,0x09,0x01,0x01,0x24,0x09,0x00,
0x03,0x23,0x00,0x0c,0x50,0x04,0x00,0x01,0x09,0x01,0x01,0x02,0x09,0x23,0x00,0x0c,0x12,0x09,0x1d,0x0a,
0x03,0x2d,0x09,0x04,0x01,0x23,0x00,0x00,0x01,0x08,0x04,0x26,0x08,0x00,0x03,0x23,0x00,0x08,0x12,0x08,
0x2d,0x08,0x05,0x00,0x37,0x08,0x01,0x08,0x04,0x50,0x09,0x01,0x41,0x08,0x25,0x08,0x00,0x03,0x50,0x04,
0x02,0x46,0x08,0x00,0x01,0x05,0x08,0x12,0x08,0x2d,0x08,0x06,0x00,0x23,0x00,0x24,0x28,0x08,0x1d,0x09,
0x07,0x29,0x08,0x09,0x24,0x09,0x00,0x03,0x23,0x00,0x13,0x01,0x08,0x05,0x2d,0x08,0x08,0x00,0x25,0x08,
0x00,0x02,0x11,0x05,0x27,0x00,0xa5,0x23,0x00,0x02,0x2a,0x08,0x01,0x08,0x02,0x25,0x08,0x00,0x0c,0x01,
0x08,0x02,0x19,0x09,0x09,0x2d,0x09,0x0a,0x00,0x43,0x08,0x25,0x08,0x00,0x2b,0x01,0x08,0x05,0x19,0x09,
0x09,0x06,0x0a,0x01,0x0b,0x02,0x2d,0x09,0x0b,0x02,0x2d,0x08,0x0c,0x01,0x50,0x08,0x01,0x19,0x09,0x09,
0x06,0x0a,0x01,0x0b,0x02,0x01,0x0c,0x08,0x2d,0x09,0x0d,0x03,0x27,0x00,0x61,0x23,0x00,0x5b,0x19,0x08,
0x09,0x01,0x09,0x04,0x2d,0x08,0x0e,0x01,0x01,0x06,0x08,0x25,0x08,0x00,0x3a,0x01,0x08,0x06,0x01,0x09,
0x04,0x2d,0x09,0x0a,0x00,0x3b,0x08,0x01,0x07,0x08,0x01,0x08,0x05,0x19,0x09,0x09,0x06,0x0a,0x01,0x0b,
0x07,0x2d,0x09,0x0b,0x02,0x2d,0x08,0x0c,0x01,0x50,0x08,0x01,0x19,0x09,0x09,0x06,0x0a,0x01,0x0b,0x07,
0x01,0x0c,0x08,0x2d,0x09,0x0d,0x03,0x27,0x00,0x16,0x23,0x00,0x10,0x01,0x08,0x05,0x19,0x09,0x09,0x2d,
0x08,0x0c,0x01,0x50,0x08,0x01,0x1a,0x08,0x09,0x23,0xff,0x33,0x01,0x08,0x05,0x26,0x08,0x00,0x03,0x23,
0x00,0x10,0x12,0x08,0x1d,0x09,0x07,0x50,0x0a,0x03,0x2d,0x09,0x0f,0x01,0x2d,0x08,0x04,0x01,0x01,0x08,
0x05,0x2d,0x08,0x10,0x00,0x37,0x08,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x85,0x00,0x00,0x00,0x88,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_370, 7, (MRB_SYM(arg), MRB_SYM(limit), MRB_OPSYM(and), MRB_SYM(rs), MRB_SYM(array), MRB_SYM(idx), MRB_SYM(len), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_370[] = "\x00\xef\x01\x12\x01\x03\x01\x0f\x01\x09\x05\x02\xfc\xff\xff\xff\x0f\x0f\x02\x02\xff\xff\xff\xff\x0f\x03\x01\x07\x02\x0e\x03\x08\x01\x0a\x03\x0a\x01\x05\x03\x06\x03\x07\x03\x02\xfd\xff\xff\xff\x0f\x02\x01\x0b\x02\x02\xff\xff\xff\xff\x0f\x0d\x01\x01\x0e\x02\xf2\xff\xff\xff\x0f\x05\x03\x15\x03\x02\xfe\xff\xff\xff\x0f\x13\x01\x12\x01\x01\x08\x02\xf8\xff\xff\xff\x0f\x01\x08\x02\xf9\xff\xff\xff\x0f\x0f\x04\x02\xfd\xff\xff\xff\x0f\x0f\x01\x13\x01\x12\x01\x01\x03\x02\xfd\xff\xff\xff\x0f\x01\x03\x02\xff\xff\xff\xff\x0f\x0a\x01\x09\x04\x1a\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_370 = {
0, 221, 135, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_370}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_370_ = &gem_mrblib_mruby_io_proc_debug_file_370;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_370 = {
367, 1, &gem_mrblib_mruby_io_proc_debug_file_370_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_370 = {
  8,14,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_370,
  gem_mrblib_mruby_io_proc_pool_370,gem_mrblib_mruby_io_proc_syms_370,NULL,
  gem_mrblib_mruby_io_proc_lv_370,
  &gem_mrblib_mruby_io_proc_debug_370,
  367,4,17,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_371, 2, (MRB_SYM(readline), MRB_SYM(EOFError), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_371[56] = {
0x33,0x00,0x10,0x00,0x12,0x03,0x11,0x04,0x01,0x05,0x01,0x48,0x04,0x2b,0x03,0x00,0x23,0x00,0x16,0x28,
0x03,0x1d,0x04,0x01,0x29,0x03,0x04,0x24,0x04,0x00,0x03,0x23,0x00,0x05,0x11,0x03,0x23,0x00,0x02,0x2a,
0x03,0x37,0x03,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x10,0x00,0x00,0x00,0x13,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_371, 2, (MRB_SYM(args), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_371[] = "\x00\x9f\x02\x04\x02\x0d\x02\x02\xfe\xff\xff\xff\x0f\x02\x01\x0b\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_371 = {
0, 221, 17, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_371}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_371_ = &gem_mrblib_mruby_io_proc_debug_file_371;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_371 = {
43, 1, &gem_mrblib_mruby_io_proc_debug_file_371_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_371 = {
  3,6,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_371,
  NULL,gem_mrblib_mruby_io_proc_syms_371,NULL,
  gem_mrblib_mruby_io_proc_lv_371,
  &gem_mrblib_mruby_io_proc_debug_371,
  43,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_372, 3, (MRB_SYM(_read_buf), MRB_IVSYM(buf), MRB_SYM(_readchar), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_372[21] = {
0x33,0x00,0x00,0x00,0x12,0x02,0x2d,0x02,0x00,0x00,0x12,0x02,0x19,0x03,0x01,0x2d,0x02,0x02,0x01,0x37,
0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_372, 1, (MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_372[] = "\x00\xa7\x02\x04\x01\x06\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_372 = {
0, 221, 7, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_372}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_372_ = &gem_mrblib_mruby_io_proc_debug_file_372;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_372 = {
21, 1, &gem_mrblib_mruby_io_proc_debug_file_372_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_372 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_372,
  NULL,gem_mrblib_mruby_io_proc_syms_372,NULL,
  gem_mrblib_mruby_io_proc_lv_372,
  &gem_mrblib_mruby_io_proc_debug_372,
  21,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_373, 2, (MRB_SYM(readchar), MRB_SYM(EOFError), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_373[50] = {
0x33,0x00,0x00,0x00,0x12,0x02,0x2d,0x02,0x00,0x00,0x23,0x00,0x16,0x28,0x02,0x1d,0x03,0x01,0x29,0x02,
0x03,0x24,0x03,0x00,0x03,0x23,0x00,0x05,0x11,0x02,0x23,0x00,0x02,0x2a,0x02,0x37,0x02,0x00,0x00,0x00,
0x00,0x04,0x00,0x00,0x00,0x0a,0x00,0x00,0x00,0x0d,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_373, 1, (MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_373[] = "\x00\xac\x02\x04\x02\x07\x02\x02\xfe\xff\xff\xff\x0f\x02\x01\x0b\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_373 = {
0, 221, 17, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_373}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_373_ = &gem_mrblib_mruby_io_proc_debug_file_373;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_373 = {
37, 1, &gem_mrblib_mruby_io_proc_debug_file_373_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_373 = {
  2,4,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_373,
  NULL,gem_mrblib_mruby_io_proc_syms_373,NULL,
  gem_mrblib_mruby_io_proc_lv_373,
  &gem_mrblib_mruby_io_proc_debug_373,
  37,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_374, 5, (MRB_SYM(_read_buf), MRB_SYM(IO), MRB_IVSYM(buf), MRB_SYM(_bufread), MRB_SYM(getbyte), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_374[30] = {
0x33,0x00,0x00,0x00,0x12,0x02,0x2d,0x02,0x00,0x00,0x1d,0x02,0x01,0x19,0x03,0x02,0x07,0x04,0x2d,0x02,
0x03,0x02,0x06,0x03,0x2d,0x02,0x04,0x01,0x37,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_374, 1, (MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_374[] = "\x00\xb4\x02\x04\x01\x06\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_374 = {
0, 221, 7, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_374}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_374_ = &gem_mrblib_mruby_io_proc_debug_file_374;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_374 = {
30, 1, &gem_mrblib_mruby_io_proc_debug_file_374_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_374 = {
  2,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_374,
  NULL,gem_mrblib_mruby_io_proc_syms_374,NULL,
  gem_mrblib_mruby_io_proc_lv_374,
  &gem_mrblib_mruby_io_proc_debug_374,
  30,0,5,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_375, 2, (MRB_SYM(readbyte), MRB_SYM(EOFError), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_375[50] = {
0x33,0x00,0x00,0x00,0x12,0x02,0x2d,0x02,0x00,0x00,0x23,0x00,0x16,0x28,0x02,0x1d,0x03,0x01,0x29,0x02,
0x03,0x24,0x03,0x00,0x03,0x23,0x00,0x05,0x11,0x02,0x23,0x00,0x02,0x2a,0x02,0x37,0x02,0x00,0x00,0x00,
0x00,0x04,0x00,0x00,0x00,0x0a,0x00,0x00,0x00,0x0d,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_375, 1, (MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_375[] = "\x00\xb9\x02\x04\x01\x07\x02\x02\xfe\xff\xff\xff\x0f\x02\x01\x0b\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_375 = {
0, 221, 17, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_375}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_375_ = &gem_mrblib_mruby_io_proc_debug_file_375;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_375 = {
37, 1, &gem_mrblib_mruby_io_proc_debug_file_375_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_375 = {
  2,4,1,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_375,
  NULL,gem_mrblib_mruby_io_proc_syms_375,NULL,
  gem_mrblib_mruby_io_proc_lv_375,
  &gem_mrblib_mruby_io_proc_debug_375,
  37,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_376, 3, (MRB_SYM(to_enum), MRB_SYM(gets), MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_376[49] = {
0x33,0x00,0x00,0x01,0x01,0x03,0x01,0x24,0x03,0x00,0x08,0x12,0x03,0x2d,0x03,0x00,0x00,0x37,0x03,0x12,
0x03,0x2d,0x03,0x01,0x00,0x01,0x02,0x03,0x25,0x03,0x00,0x0d,0x01,0x03,0x01,0x01,0x04,0x02,0x2d,0x03,
0x02,0x01,0x23,0xff,0xe6,0x12,0x03,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_376, 2, (MRB_SYM(block), MRB_SYM(line), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_376[] = "\x00\xc0\x02\x04\x01\x0f\x02\x0b\x01\x0f\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_376 = {
0, 221, 11, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_376}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_376_ = &gem_mrblib_mruby_io_proc_debug_file_376;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_376 = {
49, 1, &gem_mrblib_mruby_io_proc_debug_file_376_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_376 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_376,
  NULL,gem_mrblib_mruby_io_proc_syms_376,NULL,
  gem_mrblib_mruby_io_proc_lv_376,
  &gem_mrblib_mruby_io_proc_debug_376,
  49,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_377, 4, (MRB_SYM(each_byte), MRB_SYM(to_enum), MRB_SYM(getbyte), MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_377[52] = {
0x33,0x00,0x00,0x01,0x01,0x03,0x01,0x24,0x03,0x00,0x0b,0x12,0x03,0x10,0x04,0x00,0x2d,0x03,0x01,0x01,
0x37,0x03,0x12,0x03,0x2d,0x03,0x02,0x00,0x01,0x02,0x03,0x25,0x03,0x00,0x0d,0x01,0x03,0x01,0x01,0x04,
0x02,0x2d,0x03,0x03,0x01,0x23,0xff,0xe6,0x12,0x03,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_377, 2, (MRB_SYM(block), MRB_SYM(byte), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_377[] = "\x00\xca\x02\x04\x01\x12\x02\x0b\x01\x0f\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_377 = {
0, 221, 11, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_377}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_377_ = &gem_mrblib_mruby_io_proc_debug_file_377;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_377 = {
52, 1, &gem_mrblib_mruby_io_proc_debug_file_377_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_377 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_377,
  NULL,gem_mrblib_mruby_io_proc_syms_377,NULL,
  gem_mrblib_mruby_io_proc_lv_377,
  &gem_mrblib_mruby_io_proc_debug_377,
  52,0,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_378, 4, (MRB_SYM(each_char), MRB_SYM(to_enum), MRB_SYM(getc), MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_378[52] = {
0x33,0x00,0x00,0x01,0x01,0x03,0x01,0x24,0x03,0x00,0x0b,0x12,0x03,0x10,0x04,0x00,0x2d,0x03,0x01,0x01,
0x37,0x03,0x12,0x03,0x2d,0x03,0x02,0x00,0x01,0x02,0x03,0x25,0x03,0x00,0x0d,0x01,0x03,0x01,0x01,0x04,
0x02,0x2d,0x03,0x03,0x01,0x23,0xff,0xe6,0x12,0x03,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_378, 2, (MRB_SYM(block), MRB_SYM(char), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_378[] = "\x00\xd6\x02\x04\x01\x12\x02\x0b\x01\x0f\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_378 = {
0, 221, 11, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_378}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_378_ = &gem_mrblib_mruby_io_proc_debug_file_378;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_378 = {
52, 1, &gem_mrblib_mruby_io_proc_debug_file_378_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_378 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_378,
  NULL,gem_mrblib_mruby_io_proc_syms_378,NULL,
  gem_mrblib_mruby_io_proc_lv_378,
  &gem_mrblib_mruby_io_proc_debug_378,
  52,0,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_379, 2, (MRB_SYM(gets), MRB_OPSYM(lshift), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_379[38] = {
0x33,0x00,0x00,0x00,0x46,0x04,0x00,0x01,0x02,0x04,0x12,0x04,0x2d,0x04,0x00,0x00,0x01,0x03,0x04,0x25,
0x04,0x00,0x0d,0x01,0x04,0x02,0x01,0x05,0x03,0x2d,0x04,0x01,0x01,0x23,0xff,0xe6,0x37,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_379, 3, (MRB_OPSYM(and), MRB_SYM(ary), MRB_SYM(line), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_379[] = "\x00\xdf\x02\x04\x01\x06\x01\x0b\x01\x0f\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_379 = {
0, 221, 11, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_379}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_379_ = &gem_mrblib_mruby_io_proc_debug_file_379;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_379 = {
38, 1, &gem_mrblib_mruby_io_proc_debug_file_379_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_379 = {
  4,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_379,
  NULL,gem_mrblib_mruby_io_proc_syms_379,NULL,
  gem_mrblib_mruby_io_proc_lv_379,
  &gem_mrblib_mruby_io_proc_debug_379,
  38,0,2,0,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_380[1] = {
{IREP_TT_STR|(1<<2), {"\x0a"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_380, 8, (MRB_SYM(size), MRB_OPSYM(aref), MRB_SYM(Array), MRB_SYM_Q(kind_of), MRB_SYM(puts), MRB_SYM(to_s), MRB_SYM(write), MRB_OPSYM(neq), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_380[148] = {
0x33,0x00,0x10,0x00,0x06,0x03,0x01,0x06,0x01,0x2d,0x06,0x00,0x00,0x01,0x04,0x06,0x01,0x06,0x03,0x01,
0x07,0x04,0x42,0x06,0x25,0x06,0x00,0x60,0x01,0x06,0x01,0x01,0x07,0x03,0x2d,0x06,0x01,0x01,0x01,0x05,
0x06,0x01,0x06,0x05,0x1d,0x07,0x02,0x2d,0x06,0x03,0x01,0x25,0x06,0x00,0x0f,0x12,0x06,0x11,0x07,0x01,
0x08,0x05,0x48,0x07,0x2b,0x06,0x04,0x23,0x00,0x30,0x01,0x06,0x05,0x2d,0x06,0x05,0x00,0x01,0x05,0x06,
0x12,0x06,0x01,0x07,0x05,0x2d,0x06,0x06,0x01,0x01,0x06,0x05,0x05,0x07,0x2d,0x06,0x01,0x01,0x50,0x07,
0x00,0x2d,0x06,0x07,0x01,0x25,0x06,0x00,0x09,0x12,0x06,0x50,0x07,0x00,0x2d,0x06,0x06,0x01,0x3c,0x03,
0x01,0x23,0xff,0x94,0x01,0x06,0x04,0x06,0x07,0x41,0x06,0x25,0x06,0x00,0x09,0x12,0x06,0x50,0x07,0x00,
0x2d,0x06,0x06,0x01,0x11,0x06,0x37,0x06,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_380, 5, (MRB_SYM(args), MRB_OPSYM(and), MRB_SYM(i), MRB_SYM(len), MRB_SYM(s), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_380[] = "\x00\xe7\x02\x04\x01\x02\x01\x0a\x01\x0a\x09\x02\xf8\xff\xff\xff\x0f\x0d\x01\x0c\x01\x0f\x04\x02\xfe\xff\xff\xff\x0f\x0a\x01\x09\x01\x1d\x02\x06\x02\x14\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_380 = {
0, 221, 39, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_380}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_380_ = &gem_mrblib_mruby_io_proc_debug_file_380;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_380 = {
148, 1, &gem_mrblib_mruby_io_proc_debug_file_380_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_380 = {
  6,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_380,
  gem_mrblib_mruby_io_proc_pool_380,gem_mrblib_mruby_io_proc_syms_380,NULL,
  gem_mrblib_mruby_io_proc_lv_380,
  &gem_mrblib_mruby_io_proc_debug_380,
  148,1,8,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_381, 4, (MRB_SYM(size), MRB_OPSYM(aref), MRB_SYM(to_s), MRB_SYM(write), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_381[58] = {
0x33,0x00,0x10,0x00,0x06,0x03,0x01,0x05,0x01,0x2d,0x05,0x00,0x00,0x01,0x04,0x05,0x01,0x05,0x03,0x01,
0x06,0x04,0x42,0x05,0x25,0x05,0x00,0x1a,0x12,0x05,0x01,0x06,0x01,0x01,0x07,0x03,0x2d,0x06,0x01,0x01,
0x2d,0x06,0x02,0x00,0x2d,0x05,0x03,0x01,0x3c,0x03,0x01,0x23,0xff,0xda,0x11,0x05,0x37,0x05,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_381, 4, (MRB_SYM(args), MRB_OPSYM(and), MRB_SYM(i), MRB_SYM(len), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_381[] = "\x00\xf9\x02\x04\x01\x02\x01\x0a\x01\x0a\x02\x02\xff\xff\xff\xff\x0f\x14\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_381 = {
0, 221, 19, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_381}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_381_ = &gem_mrblib_mruby_io_proc_debug_file_381;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_381 = {
58, 1, &gem_mrblib_mruby_io_proc_debug_file_381_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_381 = {
  5,9,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_381,
  NULL,gem_mrblib_mruby_io_proc_syms_381,NULL,
  gem_mrblib_mruby_io_proc_lv_381,
  &gem_mrblib_mruby_io_proc_debug_381,
  58,0,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_382, 2, (MRB_SYM(sprintf), MRB_SYM(write), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_382[26] = {
0x33,0x00,0x10,0x00,0x12,0x03,0x12,0x04,0x11,0x05,0x01,0x06,0x01,0x48,0x05,0x2b,0x04,0x00,0x2d,0x03,
0x01,0x01,0x11,0x03,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_382, 2, (MRB_SYM(args), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_382[] = "\x00\x82\x03\x04\x01\x12\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_382 = {
0, 221, 7, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_382}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_382_ = &gem_mrblib_mruby_io_proc_debug_file_382;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_382 = {
26, 1, &gem_mrblib_mruby_io_proc_debug_file_382_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_382 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_382,
  NULL,gem_mrblib_mruby_io_proc_syms_382,NULL,
  gem_mrblib_mruby_io_proc_lv_382,
  &gem_mrblib_mruby_io_proc_debug_382,
  26,0,2,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_4[30] = {
  &gem_mrblib_mruby_io_proc_irep_353,
  &gem_mrblib_mruby_io_proc_irep_354,
  &gem_mrblib_mruby_io_proc_irep_355,
  &gem_mrblib_mruby_io_proc_irep_356,
  &gem_mrblib_mruby_io_proc_irep_357,
  &gem_mrblib_mruby_io_proc_irep_358,
  &gem_mrblib_mruby_io_proc_irep_359,
  &gem_mrblib_mruby_io_proc_irep_360,
  &gem_mrblib_mruby_io_proc_irep_361,
  &gem_mrblib_mruby_io_proc_irep_362,
  &gem_mrblib_mruby_io_proc_irep_363,
  &gem_mrblib_mruby_io_proc_irep_364,
  &gem_mrblib_mruby_io_proc_irep_365,
  &gem_mrblib_mruby_io_proc_irep_366,
  &gem_mrblib_mruby_io_proc_irep_367,
  &gem_mrblib_mruby_io_proc_irep_368,
  &gem_mrblib_mruby_io_proc_irep_369,
  &gem_mrblib_mruby_io_proc_irep_370,
  &gem_mrblib_mruby_io_proc_irep_371,
  &gem_mrblib_mruby_io_proc_irep_372,
  &gem_mrblib_mruby_io_proc_irep_373,
  &gem_mrblib_mruby_io_proc_irep_374,
  &gem_mrblib_mruby_io_proc_irep_375,
  &gem_mrblib_mruby_io_proc_irep_376,
  &gem_mrblib_mruby_io_proc_irep_377,
  &gem_mrblib_mruby_io_proc_irep_378,
  &gem_mrblib_mruby_io_proc_irep_379,
  &gem_mrblib_mruby_io_proc_irep_380,
  &gem_mrblib_mruby_io_proc_irep_381,
  &gem_mrblib_mruby_io_proc_irep_382,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_4, 41, (MRB_SYM(SEEK_SET), MRB_SYM(SEEK_CUR), MRB_SYM(SEEK_END), MRB_SYM(BUF_SIZE), MRB_SYM(open), MRB_SYM(popen), MRB_SYM(pipe), MRB_SYM(read), MRB_SYM(flush), MRB_SYM(hash), MRB_SYM(write), MRB_OPSYM(lshift), MRB_SYM_Q(eof), MRB_SYM(eof), MRB_SYM(alias_method), MRB_SYM(pos), MRB_SYM(tell), MRB_SYM_E(pos), MRB_SYM(rewind), MRB_SYM(seek), MRB_SYM(_read_buf), MRB_SYM(ungetc), MRB_SYM(ungetbyte), MRB_SYM(readline), MRB_SYM(gets), MRB_SYM(readchar), MRB_SYM(getc), MRB_SYM(readbyte), MRB_SYM(getbyte), MRB_SYM(each), MRB_SYM(each_byte), MRB_SYM(each_line), MRB_SYM(each_char), MRB_SYM(readlines), MRB_SYM(puts), MRB_SYM(print), MRB_SYM(printf), MRB_SYM(to_i), MRB_SYM(fileno), MRB_SYM_Q(tty), MRB_SYM(isatty), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_4[323] = {
0x06,0x01,0x1e,0x01,0x00,0x07,0x01,0x1e,0x01,0x01,0x08,0x01,0x1e,0x01,0x02,0x0e,0x01,0x10,0x00,0x1e,
0x01,0x03,0x12,0x01,0x61,0x01,0x57,0x02,0x00,0x5e,0x01,0x04,0x12,0x01,0x61,0x01,0x57,0x02,0x01,0x5e,
0x01,0x05,0x12,0x01,0x61,0x01,0x57,0x02,0x02,0x5e,0x01,0x06,0x12,0x01,0x61,0x01,0x57,0x02,0x03,0x5e,
0x01,0x07,0x62,0x01,0x57,0x02,0x04,0x5e,0x01,0x08,0x62,0x01,0x57,0x02,0x05,0x5e,0x01,0x09,0x62,0x01,
0x57,0x02,0x06,0x5e,0x01,0x0a,0x62,0x01,0x57,0x02,0x07,0x5e,0x01,0x0b,0x62,0x01,0x57,0x02,0x08,0x5e,
0x01,0x0c,0x12,0x01,0x10,0x02,0x0d,0x10,0x03,0x0c,0x2d,0x01,0x0e,0x02,0x62,0x01,0x57,0x02,0x09,0x5e,
0x01,0x0f,0x12,0x01,0x10,0x02,0x10,0x10,0x03,0x0f,0x2d,0x01,0x0e,0x02,0x62,0x01,0x57,0x02,0x0a,0x5e,
0x01,0x11,0x62,0x01,0x57,0x02,0x0b,0x5e,0x01,0x12,0x62,0x01,0x57,0x02,0x0c,0x5e,0x01,0x13,0x62,0x01,
0x57,0x02,0x0d,0x5e,0x01,0x14,0x62,0x01,0x57,0x02,0x0e,0x5e,0x01,0x15,0x62,0x01,0x57,0x02,0x0f,0x5e,
0x01,0x16,0x62,0x01,0x57,0x02,0x10,0x5e,0x01,0x07,0x62,0x01,0x57,0x02,0x11,0x5e,0x01,0x17,0x62,0x01,
0x57,0x02,0x12,0x5e,0x01,0x18,0x62,0x01,0x57,0x02,0x13,0x5e,0x01,0x19,0x62,0x01,0x57,0x02,0x14,0x5e,
0x01,0x1a,0x62,0x01,0x57,0x02,0x15,0x5e,0x01,0x1b,0x62,0x01,0x57,0x02,0x16,0x5e,0x01,0x1c,0x62,0x01,
0x57,0x02,0x17,0x5e,0x01,0x1d,0x62,0x01,0x57,0x02,0x18,0x5e,0x01,0x1e,0x5f,0x1f,0x1d,0x62,0x01,0x57,
0x02,0x19,0x5e,0x01,0x20,0x62,0x01,0x57,0x02,0x1a,0x5e,0x01,0x21,0x62,0x01,0x57,0x02,0x1b,0x5e,0x01,
0x22,0x62,0x01,0x57,0x02,0x1c,0x5e,0x01,0x23,0x62,0x01,0x57,0x02,0x1d,0x5e,0x01,0x24,0x12,0x01,0x10,
0x02,0x25,0x10,0x03,0x26,0x2d,0x01,0x0e,0x02,0x12,0x01,0x10,0x02,0x27,0x10,0x03,0x28,0x2d,0x01,0x0e,
0x02,0x37,0x01,};
static char gem_mrblib_mruby_io_proc_debug_lines_4[] = "\x00\x08\x05\x01\x05\x01\x05\x02\x07\x02\x0a\x0f\x0a\x12\x0a\x11\x0a\x30\x08\x06\x08\x06\x08\x0b\x08\x05\x08\x09\x0c\x02\x08\x04\x0c\x02\x08\x04\x08\x04\x08\x07\x08\x05\x08\x0a\x08\x0b\x08\x29\x08\x30\x08\x08\x08\x05\x08\x08\x08\x05\x08\x07\x08\x0a\x08\x0a\x03\x02\x08\x09\x08\x08\x08\x12\x08\x09\x08\x05\x0c\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_4 = {
0, 221, 78, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_4}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_4_ = &gem_mrblib_mruby_io_proc_debug_file_4;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_4 = {
323, 1, &gem_mrblib_mruby_io_proc_debug_file_4_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_4 = {
  1,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_4,
  NULL,gem_mrblib_mruby_io_proc_syms_4,gem_mrblib_mruby_io_proc_reps_4,
  NULL,					/* lv */
  &gem_mrblib_mruby_io_proc_debug_4,
  323,0,41,30,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_1264, 1, (MRB_SYM(read), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_1264[13] = {
0x33,0x04,0x00,0x00,0x01,0x03,0x01,0x2d,0x03,0x00,0x00,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_1264, 2, (MRB_SYM(io), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_1264[] = "\x00\x03";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_1264 = {
0, 271, 2, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_1264}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_1264_ = &gem_mrblib_mruby_io_proc_debug_file_1264;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_1264 = {
13, 1, &gem_mrblib_mruby_io_proc_debug_file_1264_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_1264 = {
  3,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_1264,
  NULL,gem_mrblib_mruby_io_proc_syms_1264,NULL,
  gem_mrblib_mruby_io_proc_lv_1264,
  &gem_mrblib_mruby_io_proc_debug_1264,
  13,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_1258[1] = {
  &gem_mrblib_mruby_io_proc_irep_1264,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_1258, 2, (MRB_SYM(IO), MRB_SYM(popen), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_1258[19] = {
0x33,0x04,0x00,0x00,0x1d,0x03,0x00,0x01,0x04,0x01,0x56,0x05,0x00,0x2e,0x03,0x01,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_1258, 2, (MRB_SYM(cmd), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_1258[] = "\x00\x02\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_1258 = {
0, 271, 4, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_1258}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_1258_ = &gem_mrblib_mruby_io_proc_debug_file_1258;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_1258 = {
19, 1, &gem_mrblib_mruby_io_proc_debug_file_1258_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_1258 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_1258,
  NULL,gem_mrblib_mruby_io_proc_syms_1258,gem_mrblib_mruby_io_proc_reps_1258,
  gem_mrblib_mruby_io_proc_lv_1258,
  &gem_mrblib_mruby_io_proc_debug_1258,
  19,0,2,1,0
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_1259[1] = {
{IREP_TT_STR|(1<<2), {"\x7c"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_1259, 9, (MRB_SYM(String), MRB_SYM_Q(is_a), MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_OPSYM(aref), MRB_SYM(IO), MRB_SYM(popen), MRB_SYM(File), MRB_SYM(open), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_1259[100] = {
0x33,0x04,0x10,0x01,0x01,0x04,0x01,0x1d,0x05,0x00,0x2d,0x04,0x01,0x01,0x24,0x04,0x00,0x09,0x12,0x04,
0x1d,0x05,0x02,0x2d,0x04,0x03,0x01,0x01,0x04,0x01,0x06,0x05,0x2d,0x04,0x04,0x01,0x50,0x05,0x00,0x41,
0x04,0x25,0x04,0x00,0x21,0x1d,0x04,0x05,0x01,0x05,0x01,0x07,0x06,0x05,0x07,0x58,0x06,0x2d,0x05,0x04,
0x01,0x46,0x05,0x01,0x01,0x06,0x02,0x48,0x05,0x01,0x06,0x03,0x2c,0x04,0x06,0x23,0x00,0x14,0x1d,0x04,
0x07,0x01,0x05,0x01,0x46,0x05,0x01,0x01,0x06,0x02,0x48,0x05,0x01,0x06,0x03,0x2c,0x04,0x08,0x37,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_1259, 3, (MRB_SYM(file), MRB_SYM(rest), MRB_SYM(block), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_1259[] = "\x00\x06\x04\x01\x17\x02\x10\x01\x21\x02";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_1259 = {
0, 271, 10, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_1259}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_1259_ = &gem_mrblib_mruby_io_proc_debug_file_1259;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_1259 = {
100, 1, &gem_mrblib_mruby_io_proc_debug_file_1259_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_1259 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_1259,
  gem_mrblib_mruby_io_proc_pool_1259,gem_mrblib_mruby_io_proc_syms_1259,NULL,
  gem_mrblib_mruby_io_proc_lv_1259,
  &gem_mrblib_mruby_io_proc_debug_1259,
  100,1,9,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_1260, 2, (0, MRB_SYM(print), ), );
static const mrb_code gem_mrblib_mruby_io_proc_iseq_1260[19] = {
0x33,0x00,0x10,0x00,0x15,0x03,0x00,0x11,0x04,0x01,0x05,0x01,0x48,0x04,0x2b,0x03,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_1260, 2, (MRB_SYM(args), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_1260[] = "\x00\x10\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_1260 = {
0, 271, 4, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_1260}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_1260_ = &gem_mrblib_mruby_io_proc_debug_file_1260;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_1260 = {
19, 1, &gem_mrblib_mruby_io_proc_debug_file_1260_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_1260 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_1260,
  NULL,gem_mrblib_mruby_io_proc_syms_1260,NULL,
  gem_mrblib_mruby_io_proc_lv_1260,
  &gem_mrblib_mruby_io_proc_debug_1260,
  19,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_1261, 2, (0, MRB_SYM(puts), ), );
static const mrb_code gem_mrblib_mruby_io_proc_iseq_1261[19] = {
0x33,0x00,0x10,0x00,0x15,0x03,0x00,0x11,0x04,0x01,0x05,0x01,0x48,0x04,0x2b,0x03,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_1261, 2, (MRB_SYM(args), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_1261[] = "\x00\x14\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_1261 = {
0, 271, 4, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_1261}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_1261_ = &gem_mrblib_mruby_io_proc_debug_file_1261;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_1261 = {
19, 1, &gem_mrblib_mruby_io_proc_debug_file_1261_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_1261 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_1261,
  NULL,gem_mrblib_mruby_io_proc_syms_1261,NULL,
  gem_mrblib_mruby_io_proc_lv_1261,
  &gem_mrblib_mruby_io_proc_debug_1261,
  19,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_1262, 2, (0, MRB_SYM(printf), ), );
static const mrb_code gem_mrblib_mruby_io_proc_iseq_1262[19] = {
0x33,0x00,0x10,0x00,0x15,0x03,0x00,0x11,0x04,0x01,0x05,0x01,0x48,0x04,0x2b,0x03,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_1262, 2, (MRB_SYM(args), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_1262[] = "\x00\x18\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_1262 = {
0, 271, 4, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_1262}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_1262_ = &gem_mrblib_mruby_io_proc_debug_file_1262;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_1262 = {
19, 1, &gem_mrblib_mruby_io_proc_debug_file_1262_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_1262 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_1262,
  NULL,gem_mrblib_mruby_io_proc_syms_1262,NULL,
  gem_mrblib_mruby_io_proc_lv_1262,
  &gem_mrblib_mruby_io_proc_debug_1262,
  19,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_1263, 2, (0, MRB_SYM(gets), ), );
static const mrb_code gem_mrblib_mruby_io_proc_iseq_1263[19] = {
0x33,0x00,0x10,0x00,0x15,0x03,0x00,0x11,0x04,0x01,0x05,0x01,0x48,0x04,0x2b,0x03,0x01,0x37,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_lv_1263, 2, (MRB_SYM(args), MRB_OPSYM(and), ), const);
static char gem_mrblib_mruby_io_proc_debug_lines_1263[] = "\x00\x1c\x04\x01";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_1263 = {
0, 271, 4, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_1263}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_1263_ = &gem_mrblib_mruby_io_proc_debug_file_1263;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_1263 = {
19, 1, &gem_mrblib_mruby_io_proc_debug_file_1263_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_1263 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_1263,
  NULL,gem_mrblib_mruby_io_proc_syms_1263,NULL,
  gem_mrblib_mruby_io_proc_lv_1263,
  &gem_mrblib_mruby_io_proc_debug_1263,
  19,0,2,0,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_5[6] = {
  &gem_mrblib_mruby_io_proc_irep_1258,
  &gem_mrblib_mruby_io_proc_irep_1259,
  &gem_mrblib_mruby_io_proc_irep_1260,
  &gem_mrblib_mruby_io_proc_irep_1261,
  &gem_mrblib_mruby_io_proc_irep_1262,
  &gem_mrblib_mruby_io_proc_irep_1263,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_5, 6, (MRB_OPSYM(tick), MRB_SYM(open), MRB_SYM(print), MRB_SYM(puts), MRB_SYM(printf), MRB_SYM(gets), ), const);
static const mrb_code gem_mrblib_mruby_io_proc_iseq_5[50] = {
0x62,0x01,0x57,0x02,0x00,0x5e,0x01,0x00,0x62,0x01,0x57,0x02,0x01,0x5e,0x01,0x01,0x62,0x01,0x57,0x02,
0x02,0x5e,0x01,0x02,0x62,0x01,0x57,0x02,0x03,0x5e,0x01,0x03,0x62,0x01,0x57,0x02,0x04,0x5e,0x01,0x04,
0x62,0x01,0x57,0x02,0x05,0x5e,0x01,0x05,0x37,0x01,};
static char gem_mrblib_mruby_io_proc_debug_lines_5[] = "\x00\x02\x08\x04\x08\x0a\x08\x04\x08\x04\x08\x04";
static mrb_irep_debug_info_file gem_mrblib_mruby_io_proc_debug_file_5 = {
0, 271, 12, mrb_debug_line_packed_map, {gem_mrblib_mruby_io_proc_debug_lines_5}};
static mrb_irep_debug_info_file *gem_mrblib_mruby_io_proc_debug_file_5_ = &gem_mrblib_mruby_io_proc_debug_file_5;
static mrb_irep_debug_info gem_mrblib_mruby_io_proc_debug_5 = {
50, 1, &gem_mrblib_mruby_io_proc_debug_file_5_};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_5 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_5,
  NULL,gem_mrblib_mruby_io_proc_syms_5,gem_mrblib_mruby_io_proc_reps_5,
  NULL,					/* lv */
  &gem_mrblib_mruby_io_proc_debug_5,
  50,0,6,6,0
};
static const mrb_irep *gem_mrblib_mruby_io_proc_reps_0[5] = {
  &gem_mrblib_mruby_io_proc_irep_1,
  &gem_mrblib_mruby_io_proc_irep_2,
  &gem_mrblib_mruby_io_proc_irep_3,
  &gem_mrblib_mruby_io_proc_irep_4,
  &gem_mrblib_mruby_io_proc_irep_5,
};
static const mrb_pool_value gem_mrblib_mruby_io_proc_pool_0[2] = {
{IREP_TT_STR|(1<<2), {"\x72"}},
{IREP_TT_STR|(1<<2), {"\x77"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_io_proc_syms_0, 13, (MRB_SYM(IO), MRB_SYM(File), MRB_SYM(StandardError), MRB_SYM(IOError), MRB_SYM(EOFError), MRB_SYM(open), MRB_SYM(STDIN), MRB_SYM(STDOUT), MRB_SYM(STDERR), 0, 0, 0, MRB_SYM(Kernel), ), );
static const mrb_code gem_mrblib_mruby_io_proc_iseq_0[135] = {
0x11,0x01,0x1d,0x02,0x00,0x5b,0x01,0x01,0x5d,0x01,0x00,0x11,0x01,0x11,0x02,0x5b,0x01,0x01,0x5d,0x01,
0x01,0x11,0x01,0x11,0x02,0x5b,0x01,0x01,0x5d,0x01,0x02,0x11,0x01,0x1d,0x02,0x02,0x5b,0x01,0x03,0x11,
0x01,0x11,0x01,0x1d,0x02,0x03,0x5b,0x01,0x04,0x11,0x01,0x11,0x01,0x11,0x02,0x5b,0x01,0x00,0x5d,0x01,
0x03,0x1d,0x01,0x00,0x06,0x02,0x50,0x03,0x00,0x2d,0x01,0x05,0x02,0x1e,0x01,0x06,0x1d,0x01,0x00,0x07,
0x02,0x50,0x03,0x01,0x2d,0x01,0x05,0x02,0x1e,0x01,0x07,0x1d,0x01,0x00,0x08,0x02,0x50,0x03,0x01,0x2d,
0x01,0x05,0x02,0x1e,0x01,0x08,0x1d,0x01,0x06,0x16,0x01,0x09,0x1d,0x01,0x07,0x16,0x01,0x0a,0x1d,0x01,
0x08,0x16,0x01,0x0b,0x11,0x01,0x5c,0x01,0x0c,0x5d,0x01,0x04,0x37,0x01,0x68,};
static const mrb_irep gem_mrblib_mruby_io_proc_irep_0 = {
  1,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_io_proc_iseq_0,
  gem_mrblib_mruby_io_proc_pool_0,gem_mrblib_mruby_io_proc_syms_0,gem_mrblib_mruby_io_proc_reps_0,
  NULL,					/* lv */
  NULL,					/* debug_info */
  135,2,13,5,0
};
static
const struct RProc gem_mrblib_mruby_io_proc[] = {{
NULL,NULL,MRB_TT_PROC,MRB_GC_RED,0,{&gem_mrblib_mruby_io_proc_irep_0},NULL,{NULL},
}};
static void
gem_mrblib_mruby_io_proc_init_syms(mrb_state *mrb)
{
  gem_mrblib_mruby_io_proc_debug_file_6.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_7.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_60.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_61.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_8.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_9.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_100.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_10.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_120.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_119.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_11.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_12.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_13.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_14.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_15.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_16.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_17.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_18.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_19.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_20.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_21.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_22.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_23.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_1.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb");
  gem_mrblib_mruby_io_proc_debug_file_342.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file_constants.rb");
  gem_mrblib_mruby_io_proc_debug_file_2.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file_constants.rb");
  gem_mrblib_mruby_io_proc_debug_file_3.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file_constants.rb");
  gem_mrblib_mruby_io_proc_debug_file_353.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_354.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_355.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_356.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_357.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_358.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_359.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_360.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_361.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_362.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_363.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_364.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_365.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_366.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_367.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_368.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_369.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_370.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_371.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_372.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_373.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_374.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_375.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_376.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_377.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_378.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_379.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_380.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_381.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_382.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_4.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb");
  gem_mrblib_mruby_io_proc_debug_file_1264.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/kernel.rb");
  gem_mrblib_mruby_io_proc_debug_file_1258.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/kernel.rb");
  gem_mrblib_mruby_io_proc_debug_file_1259.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/kernel.rb");
  gem_mrblib_mruby_io_proc_syms_1260[0] = mrb_intern_lit(mrb, "$stdout");
  gem_mrblib_mruby_io_proc_debug_file_1260.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/kernel.rb");
  gem_mrblib_mruby_io_proc_syms_1261[0] = mrb_intern_lit(mrb, "$stdout");
  gem_mrblib_mruby_io_proc_debug_file_1261.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/kernel.rb");
  gem_mrblib_mruby_io_proc_syms_1262[0] = mrb_intern_lit(mrb, "$stdout");
  gem_mrblib_mruby_io_proc_debug_file_1262.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/kernel.rb");
  gem_mrblib_mruby_io_proc_syms_1263[0] = mrb_intern_lit(mrb, "$stdin");
  gem_mrblib_mruby_io_proc_debug_file_1263.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/kernel.rb");
  gem_mrblib_mruby_io_proc_debug_file_5.filename_sym = mrb_intern_lit(mrb,"/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/kernel.rb");
  gem_mrblib_mruby_io_proc_syms_0[9] = mrb_intern_lit(mrb, "$stdin");
  gem_mrblib_mruby_io_proc_syms_0[10] = mrb_intern_lit(mrb, "$stdout");
  gem_mrblib_mruby_io_proc_syms_0[11] = mrb_intern_lit(mrb, "$stderr");
}
void mrb_mruby_io_gem_init(mrb_state *mrb);
void mrb_mruby_io_gem_final(mrb_state *mrb);

void GENERATED_TMP_mrb_mruby_io_gem_init(mrb_state *mrb) {
  int ai = mrb_gc_arena_save(mrb);
  gem_mrblib_mruby_io_proc_init_syms(mrb);
  mrb_mruby_io_gem_init(mrb);
  mrb_load_proc(mrb, gem_mrblib_mruby_io_proc);
  if (mrb->exc) {
    mrb_print_error(mrb);
    mrb_close(mrb);
    exit(EXIT_FAILURE);
  }
  struct REnv *e = mrb_vm_ci_env(mrb->c->cibase);
  mrb_vm_ci_env_set(mrb->c->cibase, NULL);
  mrb_env_unshare(mrb, e);
  mrb_gc_arena_restore(mrb, ai);
}

void GENERATED_TMP_mrb_mruby_io_gem_final(mrb_state *mrb) {
  mrb_mruby_io_gem_final(mrb);
}
